# All Documents

- smartcard
  index.html
  Package
  Package
  PUBLIC
  Smartcard utility module.
- smartcard.ATR
  smartcard.ATR.html
  Module
  Module
  PUBLIC
  ATR class managing some of the Answer To Reset content.
- smartcard.AbstractCardRequest
  smartcard.AbstractCardRequest.html
  Module
  Module
  PUBLIC
  AbstractCardRequest class.
- smartcard.Card
  smartcard.Card.html
  Module
  Module
  PUBLIC
  Card class.
- smartcard.CardConnection
  smartcard.CardConnection.html
  Module
  Module
  PUBLIC
  The CardConnection abstract class manages connections with a card and apdu transmission.
- smartcard.CardConnectionDecorator
  smartcard.CardConnectionDecorator.html
  Module
  Module
  PUBLIC
  The CardConnectionDecorator is a Decorator around the CardConnection abstract class, and allows dynamic addition of features to the CardConnection, e.g. implementing a secure channel..
- smartcard.CardConnectionEvent
  smartcard.CardConnectionEvent.html
  Module
  Module
  PUBLIC
  The CardConnectionEvent is sent to CardConnectionObserver objects when a CardConnection event occurs.
- smartcard.CardConnectionObserver
  smartcard.CardConnectionObserver.html
  Module
  Module
  PUBLIC
  CardConnectionObserver interface.
- smartcard.CardMonitoring
  smartcard.CardMonitoring.html
  Module
  Module
  PUBLIC
  Smart card insertion/removal monitoring classes.
- smartcard.CardNames
  smartcard.CardNames.html
  Module
  Module
  PUBLIC
  Card Names class
- smartcard.CardRequest
  smartcard.CardRequest.html
  Module
  Module
  PUBLIC
  Smartcard CardRequest.
- smartcard.CardService
  smartcard.CardService.html
  Module
  Module
  PUBLIC
  Card service abstract class.
- smartcard.CardType
  smartcard.CardType.html
  Module
  Module
  PUBLIC
  Abstract CarType.
- smartcard.ClassLoader
  smartcard.ClassLoader.html
  Module
  Module
  PUBLIC
  ClassLoader allows you to load modules from packages without hard-coding their class names in code; instead, they might be specified in a configuration file, as command-line parameters, or within an interface.
- smartcard.Exceptions
  smartcard.Exceptions.html
  Module
  Module
  PUBLIC
  Smartcard module exceptions.
- smartcard.ExclusiveConnectCardConnection
  smartcard.ExclusiveConnectCardConnection.html
  Module
  Module
  PUBLIC
  CardConnectionDecorator that provides exclusive use of a card.
- smartcard.ExclusiveTransmitCardConnection
  smartcard.ExclusiveTransmitCardConnection.html
  Module
  Module
  PUBLIC
  Sample CardConnectionDecorator that provides exclusive transmit()
- smartcard.Observer
  smartcard.Observer.html
  Module
  Module
  PUBLIC
  from Thinking in Python, Bruce Eckel http://python-3-patterns-idioms-test.readthedocs.org/en/latest/Observer.html
- smartcard.PassThruCardService
  smartcard.PassThruCardService.html
  Module
  Module
  PUBLIC
  Card service abstract class.
- smartcard.ReaderMonitoring
  smartcard.ReaderMonitoring.html
  Module
  Module
  PUBLIC
  Smart card reader monitoring classes.
- smartcard.Session
  smartcard.Session.html
  Class
  Class
  PUBLIC
  The Session object enables programmers to transmit APDU to smartcards.
- smartcard.Synchronization
  smartcard.Synchronization.html
  Module
  Module
  PUBLIC
  from Thinking in Python, Bruce Eckel http://python-3-patterns-idioms-test.readthedocs.org/en/latest/Observer.html
- smartcard.System
  smartcard.System.html
  Module
  Module
  PUBLIC
  Smartcard system utility functions and classes.
- smartcard.guid
  smartcard.guid.html
  Module
  Module
  PUBLIC
  smartcard.guid
- smartcard.pcsc
  smartcard.pcsc.html
  Package
  Package
  PUBLIC
  No package docstring; 7/7 modules documented
- smartcard.pcsc.PCSCCardConnection
  smartcard.pcsc.PCSCCardConnection.html
  Module
  Module
  PUBLIC
  PCSCCardConnection class manages connections thru a PCSC reader.
- smartcard.pcsc.PCSCCardRequest
  smartcard.pcsc.PCSCCardRequest.html
  Module
  Module
  PUBLIC
  PCSC Smartcard request.
- smartcard.pcsc.PCSCContext
  smartcard.pcsc.PCSCContext.html
  Module
  Module
  PUBLIC
  PCSC context singleton.
- smartcard.pcsc.PCSCExceptions
  smartcard.pcsc.PCSCExceptions.html
  Module
  Module
  PUBLIC
  Smartcard module exceptions.
- smartcard.pcsc.PCSCPart10
  smartcard.pcsc.PCSCPart10.html
  Module
  Module
  PUBLIC
  PCSCPart10: PC/SC Part 10 (pinpad)
- smartcard.pcsc.PCSCReader
  smartcard.pcsc.PCSCReader.html
  Module
  Module
  PUBLIC
  PCSCReader: concrete reader class for PCSC Readers
- smartcard.pcsc.PCSCReaderGroups
  smartcard.pcsc.PCSCReaderGroups.html
  Module
  Module
  PUBLIC
  PCSCReaderGroups organizes smartcard readers as groups.
- smartcard.pyro
  smartcard.pyro.html
  Package
  Package
  PUBLIC
  pyro (remote python) utility module.
- smartcard.pyro.PyroReader
  smartcard.pyro.PyroReader.html
  Module
  Module
  PUBLIC
  PyroReaderClient: concrete reader class for Remote Readers
- smartcard.pyro.server
  smartcard.pyro.server.html
  Package
  Package
  PUBLIC
  pyro server utility module.
- smartcard.pyro.server.PyroDaemon
  smartcard.pyro.server.PyroDaemon.html
  Module
  Module
  PUBLIC
  PyroDaemon: Wrapper class around pyro daemon
- smartcard.pyro.server.PyroEventServer
  smartcard.pyro.server.PyroEventServer.html
  Module
  Module
  PUBLIC
  Utility class to start/stop Pyro Event Server.
- smartcard.pyro.server.PyroNameServer
  smartcard.pyro.server.PyroNameServer.html
  Module
  Module
  PUBLIC
  Utility class to start/stop Pyro Name Server.
- smartcard.pyro.server.RemoteCardConnection
  smartcard.pyro.server.RemoteCardConnection.html
  Module
  Module
  PUBLIC
  RemoteCardConnection class manages connections to a remote reader thru pyro (http://www.xs4all.nl/~irmen/pyro3/).
- smartcard.pyro.server.RemoteReaderServer
  smartcard.pyro.server.RemoteReaderServer.html
  Module
  Module
  PUBLIC
  RemoteReaderServer: monitor local readers and publish them as pyro Remote Readers.
- smartcard.reader
  smartcard.reader.html
  Package
  Package
  PUBLIC
  No package docstring; 3/3 modules documented
- smartcard.reader.Reader
  smartcard.reader.Reader.html
  Module
  Module
  PUBLIC
  Smart card Reader abstract class.
- smartcard.reader.ReaderFactory
  smartcard.reader.ReaderFactory.html
  Module
  Module
  PUBLIC
  ReaderFactory: creates smartcard readers.
- smartcard.reader.ReaderGroups
  smartcard.reader.ReaderGroups.html
  Module
  Module
  PUBLIC
  ReaderGroups manages smart card reader in groups.
- smartcard.scard
  smartcard.scard.html
  Package
  Package
  PUBLIC
  No package docstring; 1/1 module documented
- smartcard.scard.scard
  smartcard.scard.scard.html
  Module
  Module
  PUBLIC
  The smartcard.scard module is a simple wrapper on top of the C language PCSC SCardXXX API.
- smartcard.sw
  smartcard.sw.html
  Package
  Package
  PUBLIC
  smartcard.sw module for status word error checking.
- smartcard.sw.ErrorChecker
  smartcard.sw.ErrorChecker.html
  Module
  Module
  PUBLIC
  Base class for status word error checkers.
- smartcard.sw.ErrorCheckingChain
  smartcard.sw.ErrorCheckingChain.html
  Module
  Module
  PUBLIC
  The error checking chain is a list of status word (sw1, sw2) error check strategies.
- smartcard.sw.ISO7816_4ErrorChecker
  smartcard.sw.ISO7816_4ErrorChecker.html
  Module
  Module
  PUBLIC
  ISO7816-4 error checking strategy.
- smartcard.sw.ISO7816_4_SW1ErrorChecker
  smartcard.sw.ISO7816_4_SW1ErrorChecker.html
  Module
  Module
  PUBLIC
  ISO7816-4 sw1 only error checker.
- smartcard.sw.ISO7816_8ErrorChecker
  smartcard.sw.ISO7816_8ErrorChecker.html
  Module
  Module
  PUBLIC
  ISO7816-8 error checker.
- smartcard.sw.ISO7816_9ErrorChecker
  smartcard.sw.ISO7816_9ErrorChecker.html
  Module
  Module
  PUBLIC
  ISO7816-9 error checker.
- smartcard.sw.SWExceptions
  smartcard.sw.SWExceptions.html
  Module
  Module
  PUBLIC
  Status Word (SW) Exceptions
- smartcard.sw.op21_ErrorChecker
  smartcard.sw.op21_ErrorChecker.html
  Module
  Module
  PUBLIC
  Open Platform 2.1 error checker.
- smartcard.ulist
  smartcard.ulist.html
  Module
  Module
  PUBLIC
  ulist is a subclass of list where items cannot appear twice in the list.
- smartcard.util
  smartcard.util.html
  Package
  Package
  PUBLIC
  smartcard.util package
- smartcard.wx
  smartcard.wx.html
  Package
  Package
  PUBLIC
  wxpython smartcard utility module.
- smartcard.wx.APDUHexValidator
  smartcard.wx.APDUHexValidator.html
  Module
  Module
  PUBLIC
  A wxValidator that matches APDU in hexadecimal such as:
- smartcard.wx.APDUTracerPanel
  smartcard.wx.APDUTracerPanel.html
  Module
  Module
  PUBLIC
  Graphical APDU Tracer.
- smartcard.wx.CardAndReaderTreePanel
  smartcard.wx.CardAndReaderTreePanel.html
  Module
  Module
  PUBLIC
  wxPython panel display cards/readers as a TreeCtrl.
- smartcard.wx.ReaderToolbar
  smartcard.wx.ReaderToolbar.html
  Module
  Module
  PUBLIC
  wxPython toolbar with reader icons implementing ReaderObserver.
- smartcard.wx.SimpleSCardApp
  smartcard.wx.SimpleSCardApp.html
  Module
  Module
  PUBLIC
  Simple wxPython wxApp for smartcard.
- smartcard.wx.SimpleSCardAppEventObserver
  smartcard.wx.SimpleSCardAppEventObserver.html
  Module
  Module
  PUBLIC
  Smartcard event observer.
- smartcard.wx.SimpleSCardAppFrame
  smartcard.wx.SimpleSCardAppFrame.html
  Module
  Module
  PUBLIC
  Simple wxpython frame for smart card application.
- smartcard.System.readers
  smartcard.System.html#readers
  Function
  Function
  PUBLIC
  Returns the list of smartcard readers in groups.
- smartcard.System.readergroups
  smartcard.System.html#readergroups
  Function
  Function
  PUBLIC
  Returns the list of reader groups.
- smartcard.listReaders
  index.html#listReaders
  Function
  Function
  PUBLIC
  Returns the list of smartcard readers.
- smartcard.scard.scard._swig_repr
  smartcard.scard.scard.html#_swig_repr
  Function
  Function
  PRIVATE
  Undocumented
- smartcard.scard.scard._swig_setattr_nondynamic_instance_variable
  smartcard.scard.scard.html#_swig_setattr_nondynamic_instance_variable
  Function
  Function
  PRIVATE
  Undocumented
- smartcard.scard.scard._swig_setattr_nondynamic_class_variable
  smartcard.scard.scard.html#_swig_setattr_nondynamic_class_variable
  Function
  Function
  PRIVATE
  Undocumented
- smartcard.scard.scard._swig_add_metaclass
  smartcard.scard.scard.html#_swig_add_metaclass
  Function
  Function
  PRIVATE
  Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass
- smartcard.scard.scard._SwigNonDynamicMeta
  smartcard.scard.scard._SwigNonDynamicMeta.html
  Class
  Class
  PRIVATE
  Meta class to enforce nondynamic attributes (no new attributes) for a class
- smartcard.scard.scard._SwigNonDynamicMeta.__setattr__
  smartcard.scard.scard._SwigNonDynamicMeta.html#__setattr__
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- smartcard.scard.scard.SCardIsValidContext
  smartcard.scard.scard.html#SCardIsValidContext
  Function
  Function
  PUBLIC
  SCardIsValidContext( hcontext) -> SCARDRETCODE
- smartcard.scard.scard.SCardGetAttrib
  smartcard.scard.scard.html#SCardGetAttrib
  Function
  Function
  PUBLIC
  SCardGetAttrib( hcard, dwAttrId) -> SCARDRETCODE
- smartcard.scard.scard.SCardSetAttrib
  smartcard.scard.scard.html#SCardSetAttrib
  Function
  Function
  PUBLIC
  SCardSetAttrib( hcard, dwAttrId, BYTELIST * ATTRIBUTESIN) -> SCARDRETCODE
- smartcard.scard.scard.SCardControl
  smartcard.scard.scard.html#SCardControl
  Function
  Function
  PUBLIC
  SCardControl( hcard, dwControlCode, byte[] inbuffer) -> SCARDRETCODE
- smartcard.scard.scard.SCardBeginTransaction
  smartcard.scard.scard.html#SCardBeginTransaction
  Function
  Function
  PUBLIC
  SCardBeginTransaction( hcard) -> SCARDRETCODE
- smartcard.scard.scard.SCardCancel
  smartcard.scard.scard.html#SCardCancel
  Function
  Function
  PUBLIC
  SCardCancel( hcontext) -> SCARDRETCODE
- smartcard.scard.scard.SCardConnect
  smartcard.scard.scard.html#SCardConnect
  Function
  Function
  PUBLIC
  SCardConnect( hcontext, readername, dwShareMode, dwPreferredProtocols) -> SCARDRETCODE
- smartcard.scard.scard.SCardDisconnect
  smartcard.scard.scard.html#SCardDisconnect
  Function
  Function
  PUBLIC
  SCardDisconnect( hcard, dwDisposition) -> SCARDRETCODE
- smartcard.scard.scard.SCardEndTransaction
  smartcard.scard.scard.html#SCardEndTransaction
  Function
  Function
  PUBLIC
  SCardEndTransaction( hcard, dwDisposition) -> SCARDRETCODE
- smartcard.scard.scard.SCardEstablishContext
  smartcard.scard.scard.html#SCardEstablishContext
  Function
  Function
  PUBLIC
  SCardEstablishContext( dwScope) -> SCARDRETCODE
- smartcard.scard.scard.SCardGetStatusChange
  smartcard.scard.scard.html#SCardGetStatusChange
  Function
  Function
  PUBLIC
  SCardGetStatusChange( hcontext, dwTimeout, tuple[] readerstatelist) -> SCARDRETCODE
- smartcard.scard.scard.SCardListReaders
  smartcard.scard.scard.html#SCardListReaders
  Function
  Function
  PUBLIC
  SCardListReaders( hcontext, [] readergroups) -> SCARDRETCODE
- smartcard.scard.scard.SCardListReaderGroups
  smartcard.scard.scard.html#SCardListReaderGroups
  Function
  Function
  PUBLIC
  SCardListReaderGroups( hcontext) -> SCARDRETCODE
- smartcard.scard.scard.SCardReconnect
  smartcard.scard.scard.html#SCardReconnect
  Function
  Function
  PUBLIC
  SCardReconnect( hcard, dwShareMode, dwPreferredProtocols, dwInitialization) -> SCARDRETCODE
- smartcard.scard.scard.SCardReleaseContext
  smartcard.scard.scard.html#SCardReleaseContext
  Function
  Function
  PUBLIC
  SCardReleaseContext( hcontext) -> SCARDRETCODE
- smartcard.scard.scard.SCardStatus
  smartcard.scard.scard.html#SCardStatus
  Function
  Function
  PUBLIC
  SCardStatus( hcard) -> SCARDRETCODE
- smartcard.scard.scard.SCardTransmit
  smartcard.scard.scard.html#SCardTransmit
  Function
  Function
  PUBLIC
  SCardTransmit( hcard, unsigned long pioSendPci, byte[] apducommand) -> SCARDRETCODE
- smartcard.scard.scard.SCARD_CTL_CODE
  smartcard.scard.scard.html#SCARD_CTL_CODE
  Function
  Function
  PUBLIC
  SCARD_CTL_CODE(long code) -> long
- smartcard.scard.scard.SCardGetErrorMessage
  smartcard.scard.scard.html#SCardGetErrorMessage
  Function
  Function
  PUBLIC
  SCardGetErrorMessage(long lErrCode) -> ERRORSTRING *
- smartcard.Exceptions.SmartcardException
  smartcard.Exceptions.SmartcardException.html
  Class
  Exception
  PUBLIC
  Base class for smartcard exceptions.
- smartcard.Exceptions.SmartcardException.__init__
  smartcard.Exceptions.SmartcardException.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.Exceptions.SmartcardException.hresult
  smartcard.Exceptions.SmartcardException.html#hresult
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.Exceptions.SmartcardException.__str__
  smartcard.Exceptions.SmartcardException.html#__str__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.Exceptions.CardConnectionException
  smartcard.Exceptions.CardConnectionException.html
  Class
  Exception
  PUBLIC
  Raised when a CardConnection class method fails.
- smartcard.Exceptions.CardRequestException
  smartcard.Exceptions.CardRequestException.html
  Class
  Exception
  PUBLIC
  Raised when a CardRequest wait fails.
- smartcard.Exceptions.CardRequestTimeoutException
  smartcard.Exceptions.CardRequestTimeoutException.html
  Class
  Exception
  PUBLIC
  Raised when a CardRequest times out.
- smartcard.Exceptions.CardRequestTimeoutException.__init__
  smartcard.Exceptions.CardRequestTimeoutException.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.Exceptions.CardServiceException
  smartcard.Exceptions.CardServiceException.html
  Class
  Exception
  PUBLIC
  Raised when a CardService class method fails.
- smartcard.Exceptions.CardServiceStoppedException
  smartcard.Exceptions.CardServiceStoppedException.html
  Class
  Exception
  PUBLIC
  Raised when the CardService was stopped
- smartcard.Exceptions.InvalidATRMaskLengthException
  smartcard.Exceptions.InvalidATRMaskLengthException.html
  Class
  Exception
  PUBLIC
  Raised when an ATR mask does not match an ATR length.
- smartcard.Exceptions.InvalidATRMaskLengthException.__init__
  smartcard.Exceptions.InvalidATRMaskLengthException.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.Exceptions.InvalidReaderException
  smartcard.Exceptions.InvalidReaderException.html
  Class
  Exception
  PUBLIC
  Raised when trying to acces an invalid smartcard reader.
- smartcard.Exceptions.InvalidReaderException.__init__
  smartcard.Exceptions.InvalidReaderException.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.Exceptions.ListReadersException
  smartcard.Exceptions.ListReadersException.html
  Class
  Exception
  PUBLIC
  Raised when smartcard readers cannot be listed.
- smartcard.Exceptions.ListReadersException.__init__
  smartcard.Exceptions.ListReadersException.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.Exceptions.NoCardException
  smartcard.Exceptions.NoCardException.html
  Class
  Exception
  PUBLIC
  Raised when no card in is present in reader.
- smartcard.Exceptions.NoCardException.__init__
  smartcard.Exceptions.NoCardException.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.Exceptions.NoReadersException
  smartcard.Exceptions.NoReadersException.html
  Class
  Exception
  PUBLIC
  Raised when the system has no smartcard reader.
- smartcard.Exceptions.NoReadersException.__init__
  smartcard.Exceptions.NoReadersException.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.CardService.CardService
  smartcard.CardService.CardService.html
  Class
  Class
  PUBLIC
  Card service abstract class.
- smartcard.CardService.CardService.__init__
  smartcard.CardService.CardService.html#__init__
  Function
  Method
  PUBLIC
  Construct a new card service and bind to a smart card in a reader.
- smartcard.CardService.CardService.connection
  smartcard.CardService.CardService.html#connection
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.CardService.CardService.cardname
  smartcard.CardService.CardService.html#cardname
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.CardService.CardService.__del__
  smartcard.CardService.CardService.html#__del__
  Function
  Method
  PUBLIC
  Destructor. Disconnect card and destroy card service resources.
- smartcard.CardService.CardService.supports
  smartcard.CardService.CardService.html#supports
  Function
  Static Method
  PUBLIC
  Undocumented
- smartcard.PassThruCardService.PassThruCardService
  smartcard.PassThruCardService.PassThruCardService.html
  Class
  Class
  PUBLIC
  Pass-thru card service class.
- smartcard.PassThruCardService.PassThruCardService.__init__
  smartcard.PassThruCardService.PassThruCardService.html#__init__
  Function
  Method
  PUBLIC
  Construct a pass-thru card service.
- smartcard.PassThruCardService.PassThruCardService.supports
  smartcard.PassThruCardService.PassThruCardService.html#supports
  Function
  Static Method
  PUBLIC
  Returns True if the cardname is supported by the card service. The PassThruCardService supports all cardnames and always returns True.
- smartcard.Session.__init__
  smartcard.Session.html#__init__
  Function
  Method
  PUBLIC
  Session constructor. Initializes a smart card session and connect to the card.
- smartcard.Session.reader
  smartcard.Session.html#reader
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.Session.readerName
  smartcard.Session.html#readerName
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.Session.cs
  smartcard.Session.html#cs
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.Session.close
  smartcard.Session.html#close
  Function
  Method
  PUBLIC
  Close the smartcard session.
- smartcard.Session.sendCommandAPDU
  smartcard.Session.html#sendCommandAPDU
  Function
  Method
  PUBLIC
  Send an APDU command to the connected smartcard.
- smartcard.Session.getATR
  smartcard.Session.html#getATR
  Function
  Method
  PUBLIC
  Returns the ATR of the connected card.
- smartcard.Session.__repr__
  smartcard.Session.html#__repr__
  Function
  Method
  PUBLIC
  Returns a string representation of the session.
- smartcard.util.PACK
  smartcard.util.html#PACK
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.util.HEX
  smartcard.util.html#HEX
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.util.UPPERCASE
  smartcard.util.html#UPPERCASE
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.util.COMMA
  smartcard.util.html#COMMA
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.util.padd
  smartcard.util.html#padd
  Function
  Function
  PUBLIC
  Padds a byte list with a constant byte value (default is x0FF)
- smartcard.util.toASCIIBytes
  smartcard.util.html#toASCIIBytes
  Function
  Function
  PUBLIC
  Returns a list of ASCII bytes from a string.
- smartcard.util.toASCIIString
  smartcard.util.html#toASCIIString
  Function
  Function
  PUBLIC
  Returns a string representing a list of ASCII bytes.
- smartcard.util.toBytes
  smartcard.util.html#toBytes
  Function
  Function
  PUBLIC
  Returns a list of bytes from a byte string
- smartcard.util.__dic_GSM_3_38__
  smartcard.util.html#__dic_GSM_3_38__
  Attribute
  Variable
  PUBLIC
  Undocumented
- smartcard.util.toGSM3_38Bytes
  smartcard.util.html#toGSM3_38Bytes
  Function
  Function
  PUBLIC
  Returns a list of bytes from a string using GSM 3.38 conversion table.
- smartcard.util.toHexString
  smartcard.util.html#toHexString
  Function
  Function
  PUBLIC
  Returns an hex string representing bytes
- smartcard.util.HexListToBinString
  smartcard.util.html#HexListToBinString
  Function
  Function
  PUBLIC
  No summary
- smartcard.util.BinStringToHexList
  smartcard.util.html#BinStringToHexList
  Function
  Function
  PUBLIC
  No summary
- smartcard.util.hl2bs
  smartcard.util.html#hl2bs
  Function
  Function
  PUBLIC
  An alias for HexListToBinString
- smartcard.util.bs2hl
  smartcard.util.html#bs2hl
  Function
  Function
  PUBLIC
  An alias for BinStringToHexList
- smartcard.ATR.ATR
  smartcard.ATR.ATR.html
  Class
  Class
  PUBLIC
  ATR class.
- smartcard.ATR.ATR.clockrateconversion
  smartcard.ATR.ATR.html#clockrateconversion
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- smartcard.ATR.ATR.bitratefactor
  smartcard.ATR.ATR.html#bitratefactor
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- smartcard.ATR.ATR.currenttable
  smartcard.ATR.ATR.html#currenttable
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- smartcard.ATR.ATR.__init__
  smartcard.ATR.ATR.html#__init__
  Function
  Method
  PUBLIC
  Construct a new atr from bytes.
- smartcard.ATR.ATR.bytes
  smartcard.ATR.ATR.html#bytes
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ATR.ATR.__checksyncbyte__
  smartcard.ATR.ATR.html#__checksyncbyte__
  Function
  Method
  PUBLIC
  Check validity of TS.
- smartcard.ATR.ATR.__initInstance__
  smartcard.ATR.ATR.html#__initInstance__
  Function
  Method
  PUBLIC
  Parse ATR and initialize members:
- smartcard.ATR.ATR.TS
  smartcard.ATR.ATR.html#TS
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ATR.ATR.T0
  smartcard.ATR.ATR.html#T0
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ATR.ATR.K
  smartcard.ATR.ATR.html#K
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ATR.ATR.TA
  smartcard.ATR.ATR.html#TA
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ATR.ATR.TB
  smartcard.ATR.ATR.html#TB
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ATR.ATR.TC
  smartcard.ATR.ATR.html#TC
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ATR.ATR.TD
  smartcard.ATR.ATR.html#TD
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ATR.ATR.Y
  smartcard.ATR.ATR.html#Y
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ATR.ATR.hasTA
  smartcard.ATR.ATR.html#hasTA
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ATR.ATR.hasTB
  smartcard.ATR.ATR.html#hasTB
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ATR.ATR.hasTC
  smartcard.ATR.ATR.html#hasTC
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ATR.ATR.hasTD
  smartcard.ATR.ATR.html#hasTD
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ATR.ATR.interfaceBytesCount
  smartcard.ATR.ATR.html#interfaceBytesCount
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ATR.ATR.historicalBytes
  smartcard.ATR.ATR.html#historicalBytes
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ATR.ATR.hasChecksum
  smartcard.ATR.ATR.html#hasChecksum
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ATR.ATR.TCK
  smartcard.ATR.ATR.html#TCK
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ATR.ATR.checksumOK
  smartcard.ATR.ATR.html#checksumOK
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ATR.ATR.FI
  smartcard.ATR.ATR.html#FI
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ATR.ATR.DI
  smartcard.ATR.ATR.html#DI
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ATR.ATR.II
  smartcard.ATR.ATR.html#II
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ATR.ATR.PI1
  smartcard.ATR.ATR.html#PI1
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ATR.ATR.N
  smartcard.ATR.ATR.html#N
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ATR.ATR.getChecksum
  smartcard.ATR.ATR.html#getChecksum
  Function
  Method
  PUBLIC
  Return the checksum of the ATR. Checksum is mandatory only for T=1.
- smartcard.ATR.ATR.getHistoricalBytes
  smartcard.ATR.ATR.html#getHistoricalBytes
  Function
  Method
  PUBLIC
  Return historical bytes.
- smartcard.ATR.ATR.getHistoricalBytesCount
  smartcard.ATR.ATR.html#getHistoricalBytesCount
  Function
  Method
  PUBLIC
  Return count of historical bytes.
- smartcard.ATR.ATR.getInterfaceBytesCount
  smartcard.ATR.ATR.html#getInterfaceBytesCount
  Function
  Method
  PUBLIC
  Return count of interface bytes.
- smartcard.ATR.ATR.getTA1
  smartcard.ATR.ATR.html#getTA1
  Function
  Method
  PUBLIC
  Return TA1 byte.
- smartcard.ATR.ATR.getTB1
  smartcard.ATR.ATR.html#getTB1
  Function
  Method
  PUBLIC
  Return TB1 byte.
- smartcard.ATR.ATR.getTC1
  smartcard.ATR.ATR.html#getTC1
  Function
  Method
  PUBLIC
  Return TC1 byte.
- smartcard.ATR.ATR.getTD1
  smartcard.ATR.ATR.html#getTD1
  Function
  Method
  PUBLIC
  Return TD1 byte.
- smartcard.ATR.ATR.getBitRateFactor
  smartcard.ATR.ATR.html#getBitRateFactor
  Function
  Method
  PUBLIC
  Return bit rate factor.
- smartcard.ATR.ATR.getClockRateConversion
  smartcard.ATR.ATR.html#getClockRateConversion
  Function
  Method
  PUBLIC
  Return clock rate conversion.
- smartcard.ATR.ATR.getProgrammingCurrent
  smartcard.ATR.ATR.html#getProgrammingCurrent
  Function
  Method
  PUBLIC
  Return maximum programming current.
- smartcard.ATR.ATR.getProgrammingVoltage
  smartcard.ATR.ATR.html#getProgrammingVoltage
  Function
  Method
  PUBLIC
  Return programming voltage.
- smartcard.ATR.ATR.getGuardTime
  smartcard.ATR.ATR.html#getGuardTime
  Function
  Method
  PUBLIC
  Return extra guard time.
- smartcard.ATR.ATR.getSupportedProtocols
  smartcard.ATR.ATR.html#getSupportedProtocols
  Function
  Method
  PUBLIC
  Returns a dictionnary of supported protocols.
- smartcard.ATR.ATR.isT0Supported
  smartcard.ATR.ATR.html#isT0Supported
  Function
  Method
  PUBLIC
  Return True if T=0 is supported.
- smartcard.ATR.ATR.isT1Supported
  smartcard.ATR.ATR.html#isT1Supported
  Function
  Method
  PUBLIC
  Return True if T=1 is supported.
- smartcard.ATR.ATR.isT15Supported
  smartcard.ATR.ATR.html#isT15Supported
  Function
  Method
  PUBLIC
  Return True if T=15 is supported.
- smartcard.ATR.ATR.dump
  smartcard.ATR.ATR.html#dump
  Function
  Method
  PUBLIC
  Dump the details of an ATR.
- smartcard.ATR.ATR.__str__
  smartcard.ATR.ATR.html#__str__
  Function
  Method
  PUBLIC
  Returns a string representation of the ATR as a strem of bytes.
- smartcard.CardType.CardType
  smartcard.CardType.CardType.html
  Class
  Class
  PUBLIC
  Abstract base class for CardTypes.
- smartcard.CardType.CardType.__init__
  smartcard.CardType.CardType.html#__init__
  Function
  Method
  PUBLIC
  CardType constructor.
- smartcard.CardType.CardType.matches
  smartcard.CardType.CardType.html#matches
  Function
  Method
  PUBLIC
  Returns true if atr and card connected match the `CardType`.
- smartcard.CardType.AnyCardType
  smartcard.CardType.AnyCardType.html
  Class
  Class
  PUBLIC
  The AnyCardType matches any card.
- smartcard.CardType.AnyCardType.__init__
  smartcard.CardType.AnyCardType.html#__init__
  Function
  Method
  PUBLIC
  CardType constructor.
- smartcard.CardType.AnyCardType.matches
  smartcard.CardType.AnyCardType.html#matches
  Function
  Method
  PUBLIC
  Always returns true, i.e. AnyCardType matches any card.
- smartcard.CardType.ATRCardType
  smartcard.CardType.ATRCardType.html
  Class
  Class
  PUBLIC
  The ATRCardType defines a card from an ATR and a mask.
- smartcard.CardType.ATRCardType.__init__
  smartcard.CardType.ATRCardType.html#__init__
  Function
  Method
  PUBLIC
  ATRCardType constructor.
- smartcard.CardType.ATRCardType.atr
  smartcard.CardType.ATRCardType.html#atr
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.CardType.ATRCardType.mask
  smartcard.CardType.ATRCardType.html#mask
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.CardType.ATRCardType.maskedatr
  smartcard.CardType.ATRCardType.html#maskedatr
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.CardType.ATRCardType.matches
  smartcard.CardType.ATRCardType.html#matches
  Function
  Method
  PUBLIC
  Returns true if the atr matches the masked CardType atr.
- smartcard.AbstractCardRequest.AbstractCardRequest
  smartcard.AbstractCardRequest.AbstractCardRequest.html
  Class
  Class
  PUBLIC
  The base class for xxxCardRequest classes.
- smartcard.AbstractCardRequest.AbstractCardRequest.__init__
  smartcard.AbstractCardRequest.AbstractCardRequest.html#__init__
  Function
  Method
  PUBLIC
  Construct new CardRequest.
- smartcard.AbstractCardRequest.AbstractCardRequest.newcardonly
  smartcard.AbstractCardRequest.AbstractCardRequest.html#newcardonly
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.AbstractCardRequest.AbstractCardRequest.readersAsked
  smartcard.AbstractCardRequest.AbstractCardRequest.html#readersAsked
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.AbstractCardRequest.AbstractCardRequest.cardType
  smartcard.AbstractCardRequest.AbstractCardRequest.html#cardType
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.AbstractCardRequest.AbstractCardRequest.cardServiceClass
  smartcard.AbstractCardRequest.AbstractCardRequest.html#cardServiceClass
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.AbstractCardRequest.AbstractCardRequest.timeout
  smartcard.AbstractCardRequest.AbstractCardRequest.html#timeout
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.AbstractCardRequest.AbstractCardRequest.getReaders
  smartcard.AbstractCardRequest.AbstractCardRequest.html#getReaders
  Function
  Method
  PUBLIC
  Returns the list or readers on which to wait for cards.
- smartcard.AbstractCardRequest.AbstractCardRequest.waitforcard
  smartcard.AbstractCardRequest.AbstractCardRequest.html#waitforcard
  Function
  Method
  PUBLIC
  Wait for card insertion and returns a card service.
- smartcard.AbstractCardRequest.AbstractCardRequest.waitforcardevent
  smartcard.AbstractCardRequest.AbstractCardRequest.html#waitforcardevent
  Function
  Method
  PUBLIC
  Wait for card insertion or removal.
- smartcard.reader.Reader.Reader
  smartcard.reader.Reader.Reader.html
  Class
  Class
  PUBLIC
  Reader abstract class.
- smartcard.reader.Reader.Reader.__init__
  smartcard.reader.Reader.Reader.html#__init__
  Function
  Method
  PUBLIC
  Constructs a new reader and store readername.
- smartcard.reader.Reader.Reader.name
  smartcard.reader.Reader.Reader.html#name
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.reader.Reader.Reader.addtoreadergroup
  smartcard.reader.Reader.Reader.html#addtoreadergroup
  Function
  Method
  PUBLIC
  Add reader to a reader group.
- smartcard.reader.Reader.Reader.removefromreadergroup
  smartcard.reader.Reader.Reader.html#removefromreadergroup
  Function
  Method
  PUBLIC
  Remove reader from a reader group.
- smartcard.reader.Reader.Reader.createConnection
  smartcard.reader.Reader.Reader.html#createConnection
  Function
  Method
  PUBLIC
  Returns a card connection thru reader.
- smartcard.reader.Reader.Reader.__eq__
  smartcard.reader.Reader.Reader.html#__eq__
  Function
  Method
  PUBLIC
  Returns True if self==other (same name).
- smartcard.reader.Reader.Reader.__hash__
  smartcard.reader.Reader.Reader.html#__hash__
  Function
  Method
  PUBLIC
  Returns a hash value for this object (self.name is unique).
- smartcard.reader.Reader.Reader.__repr__
  smartcard.reader.Reader.Reader.html#__repr__
  Function
  Method
  PUBLIC
  Returns card reader name string for `object` calls.
- smartcard.reader.Reader.Reader.__str__
  smartcard.reader.Reader.Reader.html#__str__
  Function
  Method
  PUBLIC
  Returns card reader name string for str(object) calls.
- smartcard.Card.Card
  smartcard.Card.Card.html
  Class
  Class
  PUBLIC
  Card class.
- smartcard.Card.Card.__init__
  smartcard.Card.Card.html#__init__
  Function
  Method
  PUBLIC
  Card constructor.
- smartcard.Card.Card.reader
  smartcard.Card.Card.html#reader
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.Card.Card.atr
  smartcard.Card.Card.html#atr
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.Card.Card.__repr__
  smartcard.Card.Card.html#__repr__
  Function
  Method
  PUBLIC
  Return a string representing the Card (atr and reader concatenation).
- smartcard.Card.Card.__eq__
  smartcard.Card.Card.html#__eq__
  Function
  Method
  PUBLIC
  Return True if self==other (same reader and same atr). Return False otherwise.
- smartcard.Card.Card.__ne__
  smartcard.Card.Card.html#__ne__
  Function
  Method
  PUBLIC
  Return True if self!=other (same reader and same atr).Returns False otherwise.
- smartcard.Card.Card.__hash__
  smartcard.Card.Card.html#__hash__
  Function
  Method
  PUBLIC
  Returns a hash value for this object (str(self) is unique).
- smartcard.Card.Card.createConnection
  smartcard.Card.Card.html#createConnection
  Function
  Method
  PUBLIC
  Return a CardConnection to the Card object.
- smartcard.CardConnectionEvent.CardConnectionEvent
  smartcard.CardConnectionEvent.CardConnectionEvent.html
  Class
  Class
  PUBLIC
  Base class for card connection events.
- smartcard.CardConnectionEvent.CardConnectionEvent.__init__
  smartcard.CardConnectionEvent.CardConnectionEvent.html#__init__
  Function
  Method
  PUBLIC
  No summary
- smartcard.CardConnectionEvent.CardConnectionEvent.type
  smartcard.CardConnectionEvent.CardConnectionEvent.html#type
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.CardConnectionEvent.CardConnectionEvent.args
  smartcard.CardConnectionEvent.CardConnectionEvent.html#args
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.Synchronization.synchronized
  smartcard.Synchronization.html#synchronized
  Function
  Function
  PUBLIC
  Undocumented
- smartcard.Synchronization.synchronize
  smartcard.Synchronization.html#synchronize
  Function
  Function
  PUBLIC
  Synchronize methods in the given class. Only synchronize the methods whose names are given, or all methods if names=None.
- smartcard.Synchronization.Synchronization
  smartcard.Synchronization.Synchronization.html
  Class
  Class
  PUBLIC
  Undocumented
- smartcard.Synchronization.Synchronization.__init__
  smartcard.Synchronization.Synchronization.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.Synchronization.Synchronization.mutex
  smartcard.Synchronization.Synchronization.html#mutex
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.Observer.Observer
  smartcard.Observer.Observer.html
  Class
  Class
  PUBLIC
  No class docstring; 1/1 method documented
- smartcard.Observer.Observer.update
  smartcard.Observer.Observer.html#update
  Function
  Method
  PUBLIC
  Called when the observed object is modified. You call an Observable object's notifyObservers method to notify all the object's observers of the change.
- smartcard.Observer.Observable
  smartcard.Observer.Observable.html
  Class
  Class
  PUBLIC
  No class docstring; 0/2 instance variable, 1/9 method documented
- smartcard.Observer.Observable.__init__
  smartcard.Observer.Observable.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.Observer.Observable.obs
  smartcard.Observer.Observable.html#obs
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.Observer.Observable.changed
  smartcard.Observer.Observable.html#changed
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.Observer.Observable.addObserver
  smartcard.Observer.Observable.html#addObserver
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.Observer.Observable.deleteObserver
  smartcard.Observer.Observable.html#deleteObserver
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.Observer.Observable.notifyObservers
  smartcard.Observer.Observable.html#notifyObservers
  Function
  Method
  PUBLIC
  If 'changed' indicates that this object has changed, notify all its observers, then call clearChanged(). Each observer has its update() called with two arguments: this observable object and the generic 'arg'.
- smartcard.Observer.Observable.deleteObservers
  smartcard.Observer.Observable.html#deleteObservers
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.Observer.Observable.setChanged
  smartcard.Observer.Observable.html#setChanged
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.Observer.Observable.clearChanged
  smartcard.Observer.Observable.html#clearChanged
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.Observer.Observable.hasChanged
  smartcard.Observer.Observable.html#hasChanged
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.Observer.Observable.countObservers
  smartcard.Observer.Observable.html#countObservers
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.CardConnection.CardConnection
  smartcard.CardConnection.CardConnection.html
  Class
  Class
  PUBLIC
  Card connection abstract class.
- smartcard.CardConnection.CardConnection.T0_protocol
  smartcard.CardConnection.CardConnection.html#T0_protocol
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- smartcard.CardConnection.CardConnection.T1_protocol
  smartcard.CardConnection.CardConnection.html#T1_protocol
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- smartcard.CardConnection.CardConnection.RAW_protocol
  smartcard.CardConnection.CardConnection.html#RAW_protocol
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- smartcard.CardConnection.CardConnection.T15_protocol
  smartcard.CardConnection.CardConnection.html#T15_protocol
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- smartcard.CardConnection.CardConnection.__init__
  smartcard.CardConnection.CardConnection.html#__init__
  Function
  Method
  PUBLIC
  Construct a new card connection.
- smartcard.CardConnection.CardConnection.reader
  smartcard.CardConnection.CardConnection.html#reader
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.CardConnection.CardConnection.errorcheckingchain
  smartcard.CardConnection.CardConnection.html#errorcheckingchain
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.CardConnection.CardConnection.defaultprotocol
  smartcard.CardConnection.CardConnection.html#defaultprotocol
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.CardConnection.CardConnection.__del__
  smartcard.CardConnection.CardConnection.html#__del__
  Function
  Method
  PUBLIC
  Connect to card.
- smartcard.CardConnection.CardConnection.addSWExceptionToFilter
  smartcard.CardConnection.CardConnection.html#addSWExceptionToFilter
  Function
  Method
  PUBLIC
  Add a status word exception class to be filtered.
- smartcard.CardConnection.CardConnection.addObserver
  smartcard.CardConnection.CardConnection.html#addObserver
  Function
  Method
  PUBLIC
  Add a `CardConnection` observer.
- smartcard.CardConnection.CardConnection.deleteObserver
  smartcard.CardConnection.CardConnection.html#deleteObserver
  Function
  Method
  PUBLIC
  Remove a `CardConnection` observer.
- smartcard.CardConnection.CardConnection.connect
  smartcard.CardConnection.CardConnection.html#connect
  Function
  Method
  PUBLIC
  Connect to card.
- smartcard.CardConnection.CardConnection.reconnect
  smartcard.CardConnection.CardConnection.html#reconnect
  Function
  Method
  PUBLIC
  Reconnect to card.
- smartcard.CardConnection.CardConnection.disconnect
  smartcard.CardConnection.CardConnection.html#disconnect
  Function
  Method
  PUBLIC
  Disconnect from card.
- smartcard.CardConnection.CardConnection.getATR
  smartcard.CardConnection.CardConnection.html#getATR
  Function
  Method
  PUBLIC
  Return card ATR
- smartcard.CardConnection.CardConnection.getProtocol
  smartcard.CardConnection.CardConnection.html#getProtocol
  Function
  Method
  PUBLIC
  Return bit mask for the protocol of connection, or None if no protocol set. The return value is a bit mask of CardConnection.T0_protocol, CardConnection.T1_protocol, CardConnection.RAW_protocol, CardConnection...
- smartcard.CardConnection.CardConnection.getReader
  smartcard.CardConnection.CardConnection.html#getReader
  Function
  Method
  PUBLIC
  Return card connection reader
- smartcard.CardConnection.CardConnection.setErrorCheckingChain
  smartcard.CardConnection.CardConnection.html#setErrorCheckingChain
  Function
  Method
  PUBLIC
  Add an error checking chain.
- smartcard.CardConnection.CardConnection.setProtocol
  smartcard.CardConnection.CardConnection.html#setProtocol
  Function
  Method
  PUBLIC
  Set protocol for card connection.
- smartcard.CardConnection.CardConnection.transmit
  smartcard.CardConnection.CardConnection.html#transmit
  Function
  Method
  PUBLIC
  Transmit an apdu. Internally calls doTransmit() class method and notify observers upon command/response APDU events. Subclasses must override the doTransmit() class method.
- smartcard.CardConnection.CardConnection.doTransmit
  smartcard.CardConnection.CardConnection.html#doTransmit
  Function
  Method
  PUBLIC
  Performs the command APDU transmission.
- smartcard.CardConnection.CardConnection.control
  smartcard.CardConnection.CardConnection.html#control
  Function
  Method
  PUBLIC
  Send a control command and buffer. Internally calls `doControl()` class method and notify observers upon command/response events. Subclasses must override the `doControl()` class method.
- smartcard.CardConnection.CardConnection.doControl
  smartcard.CardConnection.CardConnection.html#doControl
  Function
  Method
  PUBLIC
  Performs the command control.
- smartcard.CardConnection.CardConnection.getAttrib
  smartcard.CardConnection.CardConnection.html#getAttrib
  Function
  Method
  PUBLIC
  return the requested attribute
- smartcard.CardConnection.CardConnection.doGetAttrib
  smartcard.CardConnection.CardConnection.html#doGetAttrib
  Function
  Method
  PUBLIC
  Performs the command get attrib.
- smartcard.CardConnection.CardConnection.__enter__
  smartcard.CardConnection.CardConnection.html#__enter__
  Function
  Method
  PUBLIC
  Enter the runtime context.
- smartcard.CardConnection.CardConnection.__exit__
  smartcard.CardConnection.CardConnection.html#__exit__
  Function
  Method
  PUBLIC
  Exit the runtime context trying to disconnect.
- smartcard.CardConnectionDecorator.CardConnectionDecorator
  smartcard.CardConnectionDecorator.CardConnectionDecorator.html
  Class
  Class
  PUBLIC
  Card connection decorator class.
- smartcard.CardConnectionDecorator.CardConnectionDecorator.__init__
  smartcard.CardConnectionDecorator.CardConnectionDecorator.html#__init__
  Function
  Method
  PUBLIC
  Construct a new card connection decorator.
- smartcard.CardConnectionDecorator.CardConnectionDecorator.component
  smartcard.CardConnectionDecorator.CardConnectionDecorator.html#component
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.CardConnectionDecorator.CardConnectionDecorator.addSWExceptionToFilter
  smartcard.CardConnectionDecorator.CardConnectionDecorator.html#addSWExceptionToFilter
  Function
  Method
  PUBLIC
  call inner component addSWExceptionToFilter
- smartcard.CardConnectionDecorator.CardConnectionDecorator.addObserver
  smartcard.CardConnectionDecorator.CardConnectionDecorator.html#addObserver
  Function
  Method
  PUBLIC
  call inner component addObserver
- smartcard.CardConnectionDecorator.CardConnectionDecorator.deleteObserver
  smartcard.CardConnectionDecorator.CardConnectionDecorator.html#deleteObserver
  Function
  Method
  PUBLIC
  call inner component deleteObserver
- smartcard.CardConnectionDecorator.CardConnectionDecorator.connect
  smartcard.CardConnectionDecorator.CardConnectionDecorator.html#connect
  Function
  Method
  PUBLIC
  call inner component connect
- smartcard.CardConnectionDecorator.CardConnectionDecorator.reconnect
  smartcard.CardConnectionDecorator.CardConnectionDecorator.html#reconnect
  Function
  Method
  PUBLIC
  call inner component reconnect
- smartcard.CardConnectionDecorator.CardConnectionDecorator.disconnect
  smartcard.CardConnectionDecorator.CardConnectionDecorator.html#disconnect
  Function
  Method
  PUBLIC
  call inner component disconnect
- smartcard.CardConnectionDecorator.CardConnectionDecorator.getATR
  smartcard.CardConnectionDecorator.CardConnectionDecorator.html#getATR
  Function
  Method
  PUBLIC
  call inner component getATR
- smartcard.CardConnectionDecorator.CardConnectionDecorator.getProtocol
  smartcard.CardConnectionDecorator.CardConnectionDecorator.html#getProtocol
  Function
  Method
  PUBLIC
  call inner component getProtocol
- smartcard.CardConnectionDecorator.CardConnectionDecorator.getReader
  smartcard.CardConnectionDecorator.CardConnectionDecorator.html#getReader
  Function
  Method
  PUBLIC
  call inner component getReader
- smartcard.CardConnectionDecorator.CardConnectionDecorator.setErrorCheckingChain
  smartcard.CardConnectionDecorator.CardConnectionDecorator.html#setErrorCheckingChain
  Function
  Method
  PUBLIC
  call inner component setErrorCheckingChain
- smartcard.CardConnectionDecorator.CardConnectionDecorator.setProtocol
  smartcard.CardConnectionDecorator.CardConnectionDecorator.html#setProtocol
  Function
  Method
  PUBLIC
  call inner component setProtocol
- smartcard.CardConnectionDecorator.CardConnectionDecorator.transmit
  smartcard.CardConnectionDecorator.CardConnectionDecorator.html#transmit
  Function
  Method
  PUBLIC
  call inner component transmit
- smartcard.CardConnectionDecorator.CardConnectionDecorator.control
  smartcard.CardConnectionDecorator.CardConnectionDecorator.html#control
  Function
  Method
  PUBLIC
  call inner component control
- smartcard.CardConnectionDecorator.CardConnectionDecorator.getAttrib
  smartcard.CardConnectionDecorator.CardConnectionDecorator.html#getAttrib
  Function
  Method
  PUBLIC
  call inner component getAttrib
- smartcard.CardConnectionObserver.CardConnectionObserver
  smartcard.CardConnectionObserver.CardConnectionObserver.html
  Class
  Class
  PUBLIC
  CardConnectionObserver is a base class for objects that are to be notified upon `CardConnection` events.
- smartcard.CardConnectionObserver.CardConnectionObserver.update
  smartcard.CardConnectionObserver.CardConnectionObserver.html#update
  Function
  Method
  PUBLIC
  Called upon CardConnection event.
- smartcard.CardConnectionObserver.ConsoleCardConnectionObserver
  smartcard.CardConnectionObserver.ConsoleCardConnectionObserver.html
  Class
  Class
  PUBLIC
  Undocumented
- smartcard.CardConnectionObserver.ConsoleCardConnectionObserver.update
  smartcard.CardConnectionObserver.ConsoleCardConnectionObserver.html#update
  Function
  Method
  PUBLIC
  Called upon CardConnection event.
- smartcard.pcsc.PCSCExceptions.BaseSCardException
  smartcard.pcsc.PCSCExceptions.BaseSCardException.html
  Class
  Exception
  PUBLIC
  Base class for scard (aka PCSC) exceptions.
- smartcard.pcsc.PCSCExceptions.BaseSCardException.__init__
  smartcard.pcsc.PCSCExceptions.BaseSCardException.html#__init__
  Function
  Method
  PUBLIC
  Constructor that stores the pcsc error status.
- smartcard.pcsc.PCSCExceptions.BaseSCardException.message
  smartcard.pcsc.PCSCExceptions.BaseSCardException.html#message
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCExceptions.BaseSCardException.hresult
  smartcard.pcsc.PCSCExceptions.BaseSCardException.html#hresult
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCExceptions.BaseSCardException.__str__
  smartcard.pcsc.PCSCExceptions.BaseSCardException.html#__str__
  Function
  Method
  PUBLIC
  Returns a string representation of the exception.
- smartcard.pcsc.PCSCExceptions.AddReaderToGroupException
  smartcard.pcsc.PCSCExceptions.AddReaderToGroupException.html
  Class
  Exception
  PUBLIC
  Raised when scard fails to add a new reader to a PCSC reader group.
- smartcard.pcsc.PCSCExceptions.AddReaderToGroupException.__init__
  smartcard.pcsc.PCSCExceptions.AddReaderToGroupException.html#__init__
  Function
  Method
  PUBLIC
  Constructor that stores the pcsc error status.
- smartcard.pcsc.PCSCExceptions.AddReaderToGroupException.readername
  smartcard.pcsc.PCSCExceptions.AddReaderToGroupException.html#readername
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCExceptions.AddReaderToGroupException.groupname
  smartcard.pcsc.PCSCExceptions.AddReaderToGroupException.html#groupname
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCExceptions.EstablishContextException
  smartcard.pcsc.PCSCExceptions.EstablishContextException.html
  Class
  Exception
  PUBLIC
  Raised when scard failed to establish context with PCSC.
- smartcard.pcsc.PCSCExceptions.EstablishContextException.__init__
  smartcard.pcsc.PCSCExceptions.EstablishContextException.html#__init__
  Function
  Method
  PUBLIC
  Constructor that stores the pcsc error status.
- smartcard.pcsc.PCSCExceptions.ListReadersException
  smartcard.pcsc.PCSCExceptions.ListReadersException.html
  Class
  Exception
  PUBLIC
  Raised when scard failed to list readers.
- smartcard.pcsc.PCSCExceptions.ListReadersException.__init__
  smartcard.pcsc.PCSCExceptions.ListReadersException.html#__init__
  Function
  Method
  PUBLIC
  Constructor that stores the pcsc error status.
- smartcard.pcsc.PCSCExceptions.IntroduceReaderException
  smartcard.pcsc.PCSCExceptions.IntroduceReaderException.html
  Class
  Exception
  PUBLIC
  Raised when scard fails to introduce a new reader to PCSC.
- smartcard.pcsc.PCSCExceptions.IntroduceReaderException.__init__
  smartcard.pcsc.PCSCExceptions.IntroduceReaderException.html#__init__
  Function
  Method
  PUBLIC
  Constructor that stores the pcsc error status.
- smartcard.pcsc.PCSCExceptions.IntroduceReaderException.readername
  smartcard.pcsc.PCSCExceptions.IntroduceReaderException.html#readername
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCExceptions.ReleaseContextException
  smartcard.pcsc.PCSCExceptions.ReleaseContextException.html
  Class
  Exception
  PUBLIC
  Raised when scard failed to release PCSC context.
- smartcard.pcsc.PCSCExceptions.ReleaseContextException.__init__
  smartcard.pcsc.PCSCExceptions.ReleaseContextException.html#__init__
  Function
  Method
  PUBLIC
  Constructor that stores the pcsc error status.
- smartcard.pcsc.PCSCExceptions.RemoveReaderFromGroupException
  smartcard.pcsc.PCSCExceptions.RemoveReaderFromGroupException.html
  Class
  Exception
  PUBLIC
  Raised when scard fails to remove a reader from a PCSC reader group.
- smartcard.pcsc.PCSCExceptions.RemoveReaderFromGroupException.__init__
  smartcard.pcsc.PCSCExceptions.RemoveReaderFromGroupException.html#__init__
  Function
  Method
  PUBLIC
  Constructor that stores the pcsc error status.
- smartcard.pcsc.PCSCExceptions.RemoveReaderFromGroupException.readername
  smartcard.pcsc.PCSCExceptions.RemoveReaderFromGroupException.html#readername
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCExceptions.RemoveReaderFromGroupException.groupname
  smartcard.pcsc.PCSCExceptions.RemoveReaderFromGroupException.html#groupname
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCContext.PCSCContext
  smartcard.pcsc.PCSCContext.PCSCContext.html
  Class
  Class
  PUBLIC
  Manage a singleton pcsc context handle.
- smartcard.pcsc.PCSCContext.PCSCContext.__PCSCContextSingleton
  smartcard.pcsc.PCSCContext.PCSCContext.__PCSCContextSingleton.html
  Class
  Class
  PRIVATE
  The actual pcsc context class as a singleton.
- smartcard.pcsc.PCSCContext.PCSCContext.__PCSCContextSingleton.__init__
  smartcard.pcsc.PCSCContext.PCSCContext.__PCSCContextSingleton.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCContext.PCSCContext.__PCSCContextSingleton.hcontext
  smartcard.pcsc.PCSCContext.PCSCContext.__PCSCContextSingleton.html#hcontext
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCContext.PCSCContext.__PCSCContextSingleton.getContext
  smartcard.pcsc.PCSCContext.PCSCContext.__PCSCContextSingleton.html#getContext
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCContext.PCSCContext.__PCSCContextSingleton.releaseContext
  smartcard.pcsc.PCSCContext.PCSCContext.__PCSCContextSingleton.html#releaseContext
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCContext.PCSCContext.mutex
  smartcard.pcsc.PCSCContext.PCSCContext.html#mutex
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCContext.PCSCContext.instance
  smartcard.pcsc.PCSCContext.PCSCContext.html#instance
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCContext.PCSCContext.__init__
  smartcard.pcsc.PCSCContext.PCSCContext.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCContext.PCSCContext.__getattr__
  smartcard.pcsc.PCSCContext.PCSCContext.html#__getattr__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCContext.PCSCContext.renewContext
  smartcard.pcsc.PCSCContext.PCSCContext.html#renewContext
  Function
  Static Method
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCCardConnection.translateprotocolmask
  smartcard.pcsc.PCSCCardConnection.html#translateprotocolmask
  Function
  Function
  PUBLIC
  Translate CardConnection protocol mask into PCSC protocol mask.
- smartcard.pcsc.PCSCCardConnection.translateprotocolheader
  smartcard.pcsc.PCSCCardConnection.html#translateprotocolheader
  Function
  Function
  PUBLIC
  Translate protocol into PCSC protocol header.
- smartcard.pcsc.PCSCCardConnection.dictProtocolHeader
  smartcard.pcsc.PCSCCardConnection.html#dictProtocolHeader
  Attribute
  Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCCardConnection.dictProtocol
  smartcard.pcsc.PCSCCardConnection.html#dictProtocol
  Attribute
  Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCCardConnection.PCSCCardConnection
  smartcard.pcsc.PCSCCardConnection.PCSCCardConnection.html
  Class
  Class
  PUBLIC
  PCSCCard connection class. Handles connection with a card thru a PCSC reader.
- smartcard.pcsc.PCSCCardConnection.PCSCCardConnection.__init__
  smartcard.pcsc.PCSCCardConnection.PCSCCardConnection.html#__init__
  Function
  Method
  PUBLIC
  Construct a new PCSC card connection.
- smartcard.pcsc.PCSCCardConnection.PCSCCardConnection.hcard
  smartcard.pcsc.PCSCCardConnection.PCSCCardConnection.html#hcard
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCCardConnection.PCSCCardConnection.hcontext
  smartcard.pcsc.PCSCCardConnection.PCSCCardConnection.html#hcontext
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCCardConnection.PCSCCardConnection.__del__
  smartcard.pcsc.PCSCCardConnection.PCSCCardConnection.html#__del__
  Function
  Method
  PUBLIC
  Destructor. Clean PCSC connection resources.
- smartcard.pcsc.PCSCCardConnection.PCSCCardConnection.connect
  smartcard.pcsc.PCSCCardConnection.PCSCCardConnection.html#connect
  Function
  Method
  PUBLIC
  Connect to the card.
- smartcard.pcsc.PCSCCardConnection.PCSCCardConnection.disposition
  smartcard.pcsc.PCSCCardConnection.PCSCCardConnection.html#disposition
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCCardConnection.PCSCCardConnection.reconnect
  smartcard.pcsc.PCSCCardConnection.PCSCCardConnection.html#reconnect
  Function
  Method
  PUBLIC
  Reconnect to the card.
- smartcard.pcsc.PCSCCardConnection.PCSCCardConnection.disconnect
  smartcard.pcsc.PCSCCardConnection.PCSCCardConnection.html#disconnect
  Function
  Method
  PUBLIC
  Disconnect from the card.
- smartcard.pcsc.PCSCCardConnection.PCSCCardConnection.getATR
  smartcard.pcsc.PCSCCardConnection.PCSCCardConnection.html#getATR
  Function
  Method
  PUBLIC
  Return card ATR
- smartcard.pcsc.PCSCCardConnection.PCSCCardConnection.doTransmit
  smartcard.pcsc.PCSCCardConnection.PCSCCardConnection.html#doTransmit
  Function
  Method
  PUBLIC
  Transmit an apdu to the card and return response apdu.
- smartcard.pcsc.PCSCCardConnection.PCSCCardConnection.doControl
  smartcard.pcsc.PCSCCardConnection.PCSCCardConnection.html#doControl
  Function
  Method
  PUBLIC
  Transmit a control command to the reader and return response.
- smartcard.pcsc.PCSCCardConnection.PCSCCardConnection.doGetAttrib
  smartcard.pcsc.PCSCCardConnection.PCSCCardConnection.html#doGetAttrib
  Function
  Method
  PUBLIC
  get an attribute
- smartcard.pcsc.PCSCReader.__PCSCreaders__
  smartcard.pcsc.PCSCReader.html#__PCSCreaders__
  Function
  Function
  PUBLIC
  Returns the list of PCSC smartcard readers in PCSC group.
- smartcard.pcsc.PCSCReader.PCSCReader
  smartcard.pcsc.PCSCReader.PCSCReader.html
  Class
  Class
  PUBLIC
  PCSC reader class.
- smartcard.pcsc.PCSCReader.PCSCReader.__init__
  smartcard.pcsc.PCSCReader.PCSCReader.html#__init__
  Function
  Method
  PUBLIC
  Constructs a new PCSC reader.
- smartcard.pcsc.PCSCReader.PCSCReader.addtoreadergroup
  smartcard.pcsc.PCSCReader.PCSCReader.html#addtoreadergroup
  Function
  Method
  PUBLIC
  Add reader to a reader group.
- smartcard.pcsc.PCSCReader.PCSCReader.removefromreadergroup
  smartcard.pcsc.PCSCReader.PCSCReader.html#removefromreadergroup
  Function
  Method
  PUBLIC
  Remove a reader from a reader group
- smartcard.pcsc.PCSCReader.PCSCReader.createConnection
  smartcard.pcsc.PCSCReader.PCSCReader.html#createConnection
  Function
  Method
  PUBLIC
  Return a card connection thru PCSC reader.
- smartcard.pcsc.PCSCReader.PCSCReader.Factory
  smartcard.pcsc.PCSCReader.PCSCReader.Factory.html
  Class
  Class
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCReader.PCSCReader.Factory.create
  smartcard.pcsc.PCSCReader.PCSCReader.Factory.html#create
  Function
  Static Method
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCReader.PCSCReader.readers
  smartcard.pcsc.PCSCReader.PCSCReader.html#readers
  Function
  Static Method
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCCardRequest.signalEvent
  smartcard.pcsc.PCSCCardRequest.html#signalEvent
  Function
  Function
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCCardRequest.PCSCCardRequest
  smartcard.pcsc.PCSCCardRequest.PCSCCardRequest.html
  Class
  Class
  PUBLIC
  PCSC CardRequest class.
- smartcard.pcsc.PCSCCardRequest.PCSCCardRequest.__init__
  smartcard.pcsc.PCSCCardRequest.PCSCCardRequest.html#__init__
  Function
  Method
  PUBLIC
  Construct new PCSCCardRequest.
- smartcard.pcsc.PCSCCardRequest.PCSCCardRequest.pollinginterval
  smartcard.pcsc.PCSCCardRequest.PCSCCardRequest.html#pollinginterval
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCCardRequest.PCSCCardRequest.timeout
  smartcard.pcsc.PCSCCardRequest.PCSCCardRequest.html#timeout
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCCardRequest.PCSCCardRequest.hcontext
  smartcard.pcsc.PCSCCardRequest.PCSCCardRequest.html#hcontext
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCCardRequest.PCSCCardRequest.getReaderNames
  smartcard.pcsc.PCSCCardRequest.PCSCCardRequest.html#getReaderNames
  Function
  Method
  PUBLIC
  Returns the list of PCSC readers on which to wait for cards.
- smartcard.pcsc.PCSCCardRequest.PCSCCardRequest.waitforcard
  smartcard.pcsc.PCSCCardRequest.PCSCCardRequest.html#waitforcard
  Function
  Method
  PUBLIC
  Wait for card insertion and returns a card service.
- smartcard.pcsc.PCSCCardRequest.PCSCCardRequest.waitforcardevent
  smartcard.pcsc.PCSCCardRequest.PCSCCardRequest.html#waitforcardevent
  Function
  Method
  PUBLIC
  Wait for card insertion or removal.
- smartcard.CardRequest.CardRequest
  smartcard.CardRequest.CardRequest.html
  Class
  Class
  PUBLIC
  A CardRequest is used for waitForCard() invocations and specifies what kind of smart card an application is waited for.
- smartcard.CardRequest.CardRequest.__init__
  smartcard.CardRequest.CardRequest.html#__init__
  Function
  Method
  PUBLIC
  Construct new CardRequest.
- smartcard.CardRequest.CardRequest.pcsccardrequest
  smartcard.CardRequest.CardRequest.html#pcsccardrequest
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.CardRequest.CardRequest.getReaders
  smartcard.CardRequest.CardRequest.html#getReaders
  Function
  Method
  PUBLIC
  Returns the list or readers on which to wait for cards.
- smartcard.CardRequest.CardRequest.waitforcard
  smartcard.CardRequest.CardRequest.html#waitforcard
  Function
  Method
  PUBLIC
  Wait for card insertion and returns a card service.
- smartcard.CardRequest.CardRequest.waitforcardevent
  smartcard.CardRequest.CardRequest.html#waitforcardevent
  Function
  Method
  PUBLIC
  Wait for card insertion or removal.
- smartcard.CardMonitoring._START_ON_DEMAND_
  smartcard.CardMonitoring.html#_START_ON_DEMAND_
  Attribute
  Constant
  PRIVATE
  Undocumented
- smartcard.CardMonitoring.CardObserver
  smartcard.CardMonitoring.CardObserver.html
  Class
  Class
  PUBLIC
  CardObserver is a base abstract class for objects that are to be notified upon smart card insertion / removal.
- smartcard.CardMonitoring.CardObserver.__init__
  smartcard.CardMonitoring.CardObserver.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.CardMonitoring.CardObserver.update
  smartcard.CardMonitoring.CardObserver.html#update
  Function
  Method
  PUBLIC
  Called upon smart card insertion / removal.
- smartcard.CardMonitoring.CardMonitor
  smartcard.CardMonitoring.CardMonitor.html
  Class
  Class
  PUBLIC
  Class that monitors smart card insertion / removals. and notify observers
- smartcard.CardMonitoring.CardMonitor.__CardMonitorSingleton
  smartcard.CardMonitoring.CardMonitor.__CardMonitorSingleton.html
  Class
  Class
  PRIVATE
  The real smart card monitor class.
- smartcard.CardMonitoring.CardMonitor.__CardMonitorSingleton.__init__
  smartcard.CardMonitoring.CardMonitor.__CardMonitorSingleton.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.CardMonitoring.CardMonitor.__CardMonitorSingleton.rmthread
  smartcard.CardMonitoring.CardMonitor.__CardMonitorSingleton.html#rmthread
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.CardMonitoring.CardMonitor.__CardMonitorSingleton.addObserver
  smartcard.CardMonitoring.CardMonitor.__CardMonitorSingleton.html#addObserver
  Function
  Method
  PUBLIC
  Add an observer.
- smartcard.CardMonitoring.CardMonitor.__CardMonitorSingleton.deleteObserver
  smartcard.CardMonitoring.CardMonitor.__CardMonitorSingleton.html#deleteObserver
  Function
  Method
  PUBLIC
  Remove an observer.
- smartcard.CardMonitoring.CardMonitor.__CardMonitorSingleton.__str__
  smartcard.CardMonitoring.CardMonitor.__CardMonitorSingleton.html#__str__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.CardMonitoring.CardMonitor.instance
  smartcard.CardMonitoring.CardMonitor.html#instance
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- smartcard.CardMonitoring.CardMonitor.__init__
  smartcard.CardMonitoring.CardMonitor.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.CardMonitoring.CardMonitor.__getattr__
  smartcard.CardMonitoring.CardMonitor.html#__getattr__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.CardMonitoring.CardMonitoringThread
  smartcard.CardMonitoring.CardMonitoringThread.html
  Class
  Class
  PUBLIC
  Card insertion thread. This thread waits for card insertion.
- smartcard.CardMonitoring.CardMonitoringThread.__CardMonitoringThreadSingleton
  smartcard.CardMonitoring.CardMonitoringThread.__CardMonitoringThreadSingleton.html
  Class
  Class
  PRIVATE
  The real card monitoring thread class.
- smartcard.CardMonitoring.CardMonitoringThread.__CardMonitoringThreadSingleton.__init__
  smartcard.CardMonitoring.CardMonitoringThread.__CardMonitoringThreadSingleton.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.CardMonitoring.CardMonitoringThread.__CardMonitoringThreadSingleton.observable
  smartcard.CardMonitoring.CardMonitoringThread.__CardMonitoringThreadSingleton.html#observable
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.CardMonitoring.CardMonitoringThread.__CardMonitoringThreadSingleton.stopEvent
  smartcard.CardMonitoring.CardMonitoringThread.__CardMonitoringThreadSingleton.html#stopEvent
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.CardMonitoring.CardMonitoringThread.__CardMonitoringThreadSingleton.cards
  smartcard.CardMonitoring.CardMonitoringThread.__CardMonitoringThreadSingleton.html#cards
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.CardMonitoring.CardMonitoringThread.__CardMonitoringThreadSingleton.run
  smartcard.CardMonitoring.CardMonitoringThread.__CardMonitoringThreadSingleton.html#run
  Function
  Method
  PUBLIC
  Runs until stopEvent is notified, and notify observers of all card insertion/removal.
- smartcard.CardMonitoring.CardMonitoringThread.__CardMonitoringThreadSingleton.cardrequest
  smartcard.CardMonitoring.CardMonitoringThread.__CardMonitoringThreadSingleton.html#cardrequest
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.CardMonitoring.CardMonitoringThread.__CardMonitoringThreadSingleton.stop
  smartcard.CardMonitoring.CardMonitoringThread.__CardMonitoringThreadSingleton.html#stop
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.CardMonitoring.CardMonitoringThread.instance
  smartcard.CardMonitoring.CardMonitoringThread.html#instance
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- smartcard.CardMonitoring.CardMonitoringThread.__init__
  smartcard.CardMonitoring.CardMonitoringThread.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.CardMonitoring.CardMonitoringThread.join
  smartcard.CardMonitoring.CardMonitoringThread.html#join
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.CardMonitoring.CardMonitoringThread.__getattr__
  smartcard.CardMonitoring.CardMonitoringThread.html#__getattr__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.CardNames.__CardNames__
  smartcard.CardNames.__CardNames__.html
  Class
  Class
  PUBLIC
  __CardNames__ inner class.
- smartcard.CardNames.__CardNames__.__init__
  smartcard.CardNames.__CardNames__.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.CardNames.__CardNames__.db
  smartcard.CardNames.__CardNames__.html#db
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.CardNames.__CardNames__.__del__
  smartcard.CardNames.__CardNames__.html#__del__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.CardNames.__CardNames__.add
  smartcard.CardNames.__CardNames__.html#add
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.CardNames.__CardNames__.delete
  smartcard.CardNames.__CardNames__.html#delete
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.CardNames.__CardNames__.dump
  smartcard.CardNames.__CardNames__.html#dump
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.CardNames.__CardNames__.find
  smartcard.CardNames.__CardNames__.html#find
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.CardNames.CardNames
  smartcard.CardNames.CardNames.html
  Class
  Class
  PUBLIC
  The CardNames organizes cards by a unique name and an associated `smartcard.CardType.CardType`.
- smartcard.CardNames.CardNames.instance
  smartcard.CardNames.CardNames.html#instance
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- smartcard.CardNames.CardNames.__init__
  smartcard.CardNames.CardNames.html#__init__
  Function
  Method
  PUBLIC
  Constructor: create a single instance of __readergroups on first call
- smartcard.CardNames.CardNames.__getattr__
  smartcard.CardNames.CardNames.html#__getattr__
  Function
  Method
  PUBLIC
  All operators redirected to inner class.
- smartcard.ClassLoader.get_mod
  smartcard.ClassLoader.html#get_mod
  Function
  Function
  PUBLIC
  Import a module.
- smartcard.ClassLoader.get_func
  smartcard.ClassLoader.html#get_func
  Function
  Function
  PUBLIC
  Retrieve a function object from a full dotted-package name.
- smartcard.ClassLoader.get_class
  smartcard.ClassLoader.html#get_class
  Function
  Function
  PUBLIC
  Load a module and retrieve a class (NOT an instance).
- smartcard.ExclusiveConnectCardConnection.ExclusiveConnectCardConnection
  smartcard.ExclusiveConnectCardConnection.ExclusiveConnectCardConnection.html
  Class
  Class
  PUBLIC
  This decorator uses exclusive access to the card during connection to prevent other processes to connect to this card.
- smartcard.ExclusiveConnectCardConnection.ExclusiveConnectCardConnection.__init__
  smartcard.ExclusiveConnectCardConnection.ExclusiveConnectCardConnection.html#__init__
  Function
  Method
  PUBLIC
  Construct a new card connection decorator.
- smartcard.ExclusiveConnectCardConnection.ExclusiveConnectCardConnection.connect
  smartcard.ExclusiveConnectCardConnection.ExclusiveConnectCardConnection.html#connect
  Function
  Method
  PUBLIC
  Disconnect and reconnect in exclusive mode PCSCCardconnections.
- smartcard.ExclusiveTransmitCardConnection.ExclusiveTransmitCardConnection
  smartcard.ExclusiveTransmitCardConnection.ExclusiveTransmitCardConnection.html
  Class
  Class
  PUBLIC
  This decorator uses `SCardBeginTransaction`/`SCardEndTransaction` to preserve other processes of threads to access the card during transmit().
- smartcard.ExclusiveTransmitCardConnection.ExclusiveTransmitCardConnection.__init__
  smartcard.ExclusiveTransmitCardConnection.ExclusiveTransmitCardConnection.html#__init__
  Function
  Method
  PUBLIC
  Construct a new card connection decorator.
- smartcard.ExclusiveTransmitCardConnection.ExclusiveTransmitCardConnection.lock
  smartcard.ExclusiveTransmitCardConnection.ExclusiveTransmitCardConnection.html#lock
  Function
  Method
  PUBLIC
  Lock card with `SCardBeginTransaction`.
- smartcard.ExclusiveTransmitCardConnection.ExclusiveTransmitCardConnection.unlock
  smartcard.ExclusiveTransmitCardConnection.ExclusiveTransmitCardConnection.html#unlock
  Function
  Method
  PUBLIC
  Unlock card with `SCardEndTransaction`.
- smartcard.ExclusiveTransmitCardConnection.ExclusiveTransmitCardConnection.transmit
  smartcard.ExclusiveTransmitCardConnection.ExclusiveTransmitCardConnection.html#transmit
  Function
  Method
  PUBLIC
  Gain exclusive access to card during APDU transmission for if this decorator decorates a PCSCCardConnection.
- smartcard.ReaderMonitoring.ReaderObserver
  smartcard.ReaderMonitoring.ReaderObserver.html
  Class
  Class
  PUBLIC
  ReaderObserver is a base abstract class for objects that are to be notified upon smartcard reader insertion/removal.
- smartcard.ReaderMonitoring.ReaderObserver.__init__
  smartcard.ReaderMonitoring.ReaderObserver.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.ReaderMonitoring.ReaderObserver.update
  smartcard.ReaderMonitoring.ReaderObserver.html#update
  Function
  Method
  PUBLIC
  Called upon reader insertion/removal.
- smartcard.ReaderMonitoring.ReaderMonitor
  smartcard.ReaderMonitoring.ReaderMonitor.html
  Class
  Class
  PUBLIC
  Class that monitors reader insertion/removal. and notify observers
- smartcard.ReaderMonitoring.ReaderMonitor.__shared_state
  smartcard.ReaderMonitoring.ReaderMonitor.html#__shared_state
  Attribute
  Class Variable
  PRIVATE
  Undocumented
- smartcard.ReaderMonitoring.ReaderMonitor.__init__
  smartcard.ReaderMonitoring.ReaderMonitor.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.ReaderMonitoring.ReaderMonitor.__dict__
  smartcard.ReaderMonitoring.ReaderMonitor.html#__dict__
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ReaderMonitoring.ReaderMonitor.startOnDemand
  smartcard.ReaderMonitoring.ReaderMonitor.html#startOnDemand
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ReaderMonitoring.ReaderMonitor.readerProc
  smartcard.ReaderMonitoring.ReaderMonitor.html#readerProc
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ReaderMonitoring.ReaderMonitor.period
  smartcard.ReaderMonitoring.ReaderMonitor.html#period
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ReaderMonitoring.ReaderMonitor.rmthread
  smartcard.ReaderMonitoring.ReaderMonitor.html#rmthread
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ReaderMonitoring.ReaderMonitor.addObserver
  smartcard.ReaderMonitoring.ReaderMonitor.html#addObserver
  Function
  Method
  PUBLIC
  Add an observer.
- smartcard.ReaderMonitoring.ReaderMonitor.deleteObserver
  smartcard.ReaderMonitoring.ReaderMonitor.html#deleteObserver
  Function
  Method
  PUBLIC
  Remove an observer.
- smartcard.ReaderMonitoring.ReaderMonitor.__str__
  smartcard.ReaderMonitoring.ReaderMonitor.html#__str__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.ReaderMonitoring.ReaderMonitoringThread
  smartcard.ReaderMonitoring.ReaderMonitoringThread.html
  Class
  Class
  PUBLIC
  Reader insertion thread. This thread polls for pcsc reader insertion, since no reader insertion event is available in pcsc.
- smartcard.ReaderMonitoring.ReaderMonitoringThread.__shared_state
  smartcard.ReaderMonitoring.ReaderMonitoringThread.html#__shared_state
  Attribute
  Class Variable
  PRIVATE
  Undocumented
- smartcard.ReaderMonitoring.ReaderMonitoringThread.__init__
  smartcard.ReaderMonitoring.ReaderMonitoringThread.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.ReaderMonitoring.ReaderMonitoringThread.__dict__
  smartcard.ReaderMonitoring.ReaderMonitoringThread.html#__dict__
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ReaderMonitoring.ReaderMonitoringThread.observable
  smartcard.ReaderMonitoring.ReaderMonitoringThread.html#observable
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ReaderMonitoring.ReaderMonitoringThread.stopEvent
  smartcard.ReaderMonitoring.ReaderMonitoringThread.html#stopEvent
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ReaderMonitoring.ReaderMonitoringThread.readers
  smartcard.ReaderMonitoring.ReaderMonitoringThread.html#readers
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ReaderMonitoring.ReaderMonitoringThread.readerProc
  smartcard.ReaderMonitoring.ReaderMonitoringThread.html#readerProc
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ReaderMonitoring.ReaderMonitoringThread.period
  smartcard.ReaderMonitoring.ReaderMonitoringThread.html#period
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.ReaderMonitoring.ReaderMonitoringThread.run
  smartcard.ReaderMonitoring.ReaderMonitoringThread.html#run
  Function
  Method
  PUBLIC
  Runs until stopEvent is notified, and notify observers of all reader insertion/removal.
- smartcard.ReaderMonitoring.ReaderMonitoringThread.stop
  smartcard.ReaderMonitoring.ReaderMonitoringThread.html#stop
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.guid.strToGUID
  smartcard.guid.html#strToGUID
  Function
  Function
  PUBLIC
  Converts a GUID string into a list of bytes.
- smartcard.guid.GUIDToStr
  smartcard.guid.html#GUIDToStr
  Function
  Function
  PUBLIC
  Converts a GUID sequence of bytes into a string.
- smartcard.pcsc.PCSCPart10.CM_IOCTL_GET_FEATURE_REQUEST
  smartcard.pcsc.PCSCPart10.html#CM_IOCTL_GET_FEATURE_REQUEST
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.FEATURE_VERIFY_PIN_START
  smartcard.pcsc.PCSCPart10.html#FEATURE_VERIFY_PIN_START
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.FEATURE_VERIFY_PIN_FINISH
  smartcard.pcsc.PCSCPart10.html#FEATURE_VERIFY_PIN_FINISH
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.FEATURE_MODIFY_PIN_START
  smartcard.pcsc.PCSCPart10.html#FEATURE_MODIFY_PIN_START
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.FEATURE_MODIFY_PIN_FINISH
  smartcard.pcsc.PCSCPart10.html#FEATURE_MODIFY_PIN_FINISH
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.FEATURE_GET_KEY_PRESSED
  smartcard.pcsc.PCSCPart10.html#FEATURE_GET_KEY_PRESSED
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.FEATURE_VERIFY_PIN_DIRECT
  smartcard.pcsc.PCSCPart10.html#FEATURE_VERIFY_PIN_DIRECT
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.FEATURE_MODIFY_PIN_DIRECT
  smartcard.pcsc.PCSCPart10.html#FEATURE_MODIFY_PIN_DIRECT
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.FEATURE_MCT_READER_DIRECT
  smartcard.pcsc.PCSCPart10.html#FEATURE_MCT_READER_DIRECT
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.FEATURE_MCT_UNIVERSAL
  smartcard.pcsc.PCSCPart10.html#FEATURE_MCT_UNIVERSAL
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.FEATURE_IFD_PIN_PROPERTIES
  smartcard.pcsc.PCSCPart10.html#FEATURE_IFD_PIN_PROPERTIES
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.FEATURE_ABORT
  smartcard.pcsc.PCSCPart10.html#FEATURE_ABORT
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.FEATURE_SET_SPE_MESSAGE
  smartcard.pcsc.PCSCPart10.html#FEATURE_SET_SPE_MESSAGE
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.FEATURE_VERIFY_PIN_DIRECT_APP_ID
  smartcard.pcsc.PCSCPart10.html#FEATURE_VERIFY_PIN_DIRECT_APP_ID
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.FEATURE_MODIFY_PIN_DIRECT_APP_ID
  smartcard.pcsc.PCSCPart10.html#FEATURE_MODIFY_PIN_DIRECT_APP_ID
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.FEATURE_WRITE_DISPLAY
  smartcard.pcsc.PCSCPart10.html#FEATURE_WRITE_DISPLAY
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.FEATURE_GET_KEY
  smartcard.pcsc.PCSCPart10.html#FEATURE_GET_KEY
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.FEATURE_IFD_DISPLAY_PROPERTIES
  smartcard.pcsc.PCSCPart10.html#FEATURE_IFD_DISPLAY_PROPERTIES
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.FEATURE_GET_TLV_PROPERTIES
  smartcard.pcsc.PCSCPart10.html#FEATURE_GET_TLV_PROPERTIES
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.FEATURE_CCID_ESC_COMMAND
  smartcard.pcsc.PCSCPart10.html#FEATURE_CCID_ESC_COMMAND
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.Features
  smartcard.pcsc.PCSCPart10.html#Features
  Attribute
  Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.PCSCv2_PART10_PROPERTY_wLcdLayout
  smartcard.pcsc.PCSCPart10.html#PCSCv2_PART10_PROPERTY_wLcdLayout
  Attribute
  Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.PCSCv2_PART10_PROPERTY_bEntryValidationCondition
  smartcard.pcsc.PCSCPart10.html#PCSCv2_PART10_PROPERTY_bEntryValidationCondition
  Attribute
  Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.PCSCv2_PART10_PROPERTY_bTimeOut2
  smartcard.pcsc.PCSCPart10.html#PCSCv2_PART10_PROPERTY_bTimeOut2
  Attribute
  Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.PCSCv2_PART10_PROPERTY_wLcdMaxCharacters
  smartcard.pcsc.PCSCPart10.html#PCSCv2_PART10_PROPERTY_wLcdMaxCharacters
  Attribute
  Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.PCSCv2_PART10_PROPERTY_wLcdMaxLines
  smartcard.pcsc.PCSCPart10.html#PCSCv2_PART10_PROPERTY_wLcdMaxLines
  Attribute
  Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.PCSCv2_PART10_PROPERTY_bMinPINSize
  smartcard.pcsc.PCSCPart10.html#PCSCv2_PART10_PROPERTY_bMinPINSize
  Attribute
  Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.PCSCv2_PART10_PROPERTY_bMaxPINSize
  smartcard.pcsc.PCSCPart10.html#PCSCv2_PART10_PROPERTY_bMaxPINSize
  Attribute
  Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.PCSCv2_PART10_PROPERTY_sFirmwareID
  smartcard.pcsc.PCSCPart10.html#PCSCv2_PART10_PROPERTY_sFirmwareID
  Attribute
  Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.PCSCv2_PART10_PROPERTY_bPPDUSupport
  smartcard.pcsc.PCSCPart10.html#PCSCv2_PART10_PROPERTY_bPPDUSupport
  Attribute
  Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.PCSCv2_PART10_PROPERTY_dwMaxAPDUDataSize
  smartcard.pcsc.PCSCPart10.html#PCSCv2_PART10_PROPERTY_dwMaxAPDUDataSize
  Attribute
  Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.PCSCv2_PART10_PROPERTY_wIdVendor
  smartcard.pcsc.PCSCPart10.html#PCSCv2_PART10_PROPERTY_wIdVendor
  Attribute
  Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.PCSCv2_PART10_PROPERTY_wIdProduct
  smartcard.pcsc.PCSCPart10.html#PCSCv2_PART10_PROPERTY_wIdProduct
  Attribute
  Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.Properties
  smartcard.pcsc.PCSCPart10.html#Properties
  Attribute
  Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCPart10.parseFeatureRequest
  smartcard.pcsc.PCSCPart10.html#parseFeatureRequest
  Function
  Function
  PUBLIC
  Get the list of Part10 features supported by the reader.
- smartcard.pcsc.PCSCPart10.getFeatureRequest
  smartcard.pcsc.PCSCPart10.html#getFeatureRequest
  Function
  Function
  PUBLIC
  Get the list of Part10 features supported by the reader.
- smartcard.pcsc.PCSCPart10.hasFeature
  smartcard.pcsc.PCSCPart10.html#hasFeature
  Function
  Function
  PUBLIC
  return the controlCode for a feature or None
- smartcard.pcsc.PCSCPart10.getPinProperties
  smartcard.pcsc.PCSCPart10.html#getPinProperties
  Function
  Function
  PUBLIC
  return the PIN_PROPERTIES structure
- smartcard.pcsc.PCSCPart10.getTlvProperties
  smartcard.pcsc.PCSCPart10.html#getTlvProperties
  Function
  Function
  PUBLIC
  return the GET_TLV_PROPERTIES structure
- smartcard.pcsc.PCSCPart10.parseTlvProperties
  smartcard.pcsc.PCSCPart10.html#parseTlvProperties
  Function
  Function
  PUBLIC
  return the GET_TLV_PROPERTIES structure
- smartcard.ulist.ulist
  smartcard.ulist.ulist.html
  Class
  Class
  PUBLIC
  ulist ensures that all items are unique and provides an __onadditem__ hook to perform custom action in subclasses.
- smartcard.ulist.ulist.__init__
  smartcard.ulist.ulist.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.ulist.ulist.__add__
  smartcard.ulist.ulist.html#__add__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.ulist.ulist.__iadd__
  smartcard.ulist.ulist.html#__iadd__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.ulist.ulist.__radd__
  smartcard.ulist.ulist.html#__radd__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.ulist.ulist.append
  smartcard.ulist.ulist.html#append
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.ulist.ulist.insert
  smartcard.ulist.ulist.html#insert
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.ulist.ulist.pop
  smartcard.ulist.ulist.html#pop
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.ulist.ulist.remove
  smartcard.ulist.ulist.html#remove
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.ulist.ulist.__remove_duplicates
  smartcard.ulist.ulist.html#__remove_duplicates
  Function
  Method
  PRIVATE
  Remove from other items already in list.
- smartcard.ulist.ulist.__appendother__
  smartcard.ulist.ulist.html#__appendother__
  Function
  Method
  PUBLIC
  Append other to object.
- smartcard.ulist.ulist.__onadditem__
  smartcard.ulist.ulist.html#__onadditem__
  Function
  Method
  PUBLIC
  Called for each item added. Override in subclasses for adding custom action.
- smartcard.ulist.ulist.__onremoveitem__
  smartcard.ulist.ulist.html#__onremoveitem__
  Function
  Method
  PUBLIC
  Called for each item removed. Override in subclasses for adding custom action.
- smartcard.reader.ReaderGroups.BadReaderGroupException
  smartcard.reader.ReaderGroups.BadReaderGroupException.html
  Class
  Exception
  PUBLIC
  Raised when trying to add an invalid reader group.
- smartcard.reader.ReaderGroups.BadReaderGroupException.__init__
  smartcard.reader.ReaderGroups.BadReaderGroupException.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.reader.ReaderGroups.DeleteSCardDefaultReaderGroupException
  smartcard.reader.ReaderGroups.DeleteSCardDefaultReaderGroupException.html
  Class
  Exception
  PUBLIC
  Raised when trying to delete SCard$DefaultReaders reader group.
- smartcard.reader.ReaderGroups.DeleteSCardDefaultReaderGroupException.__init__
  smartcard.reader.ReaderGroups.DeleteSCardDefaultReaderGroupException.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.reader.ReaderGroups.innerreadergroups
  smartcard.reader.ReaderGroups.innerreadergroups.html
  Class
  Class
  PUBLIC
  Smartcard readers groups private class.
- smartcard.reader.ReaderGroups.innerreadergroups.__init__
  smartcard.reader.ReaderGroups.innerreadergroups.html#__init__
  Function
  Method
  PUBLIC
  Retrieve and store list of reader groups
- smartcard.reader.ReaderGroups.innerreadergroups.unremovablegroups
  smartcard.reader.ReaderGroups.innerreadergroups.html#unremovablegroups
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.reader.ReaderGroups.innerreadergroups.__onadditem__
  smartcard.reader.ReaderGroups.innerreadergroups.html#__onadditem__
  Function
  Method
  PUBLIC
  Called when a reader group is added.
- smartcard.reader.ReaderGroups.innerreadergroups.__onremoveitem__
  smartcard.reader.ReaderGroups.innerreadergroups.html#__onremoveitem__
  Function
  Method
  PUBLIC
  Called when a reader group is added.
- smartcard.reader.ReaderGroups.innerreadergroups.__iter__
  smartcard.reader.ReaderGroups.innerreadergroups.html#__iter__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.reader.ReaderGroups.innerreadergroups.next
  smartcard.reader.ReaderGroups.innerreadergroups.html#next
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.reader.ReaderGroups.innerreadergroups.getreadergroups
  smartcard.reader.ReaderGroups.innerreadergroups.html#getreadergroups
  Function
  Method
  PUBLIC
  Returns the list of smartcard reader groups.
- smartcard.reader.ReaderGroups.innerreadergroups.addreadergroup
  smartcard.reader.ReaderGroups.innerreadergroups.html#addreadergroup
  Function
  Method
  PUBLIC
  Add a reader group
- smartcard.reader.ReaderGroups.innerreadergroups.removereadergroup
  smartcard.reader.ReaderGroups.innerreadergroups.html#removereadergroup
  Function
  Method
  PUBLIC
  Remove a reader group
- smartcard.reader.ReaderGroups.innerreadergroups.addreadertogroup
  smartcard.reader.ReaderGroups.innerreadergroups.html#addreadertogroup
  Function
  Method
  PUBLIC
  Add a reader to a reader group
- smartcard.reader.ReaderGroups.innerreadergroups.removereaderfromgroup
  smartcard.reader.ReaderGroups.innerreadergroups.html#removereaderfromgroup
  Function
  Method
  PUBLIC
  Remove a reader from a reader group
- smartcard.reader.ReaderGroups.readergroups
  smartcard.reader.ReaderGroups.readergroups.html
  Class
  Class
  PUBLIC
  ReadersGroups organizes smart card reader as groups.
- smartcard.reader.ReaderGroups.readergroups.instance
  smartcard.reader.ReaderGroups.readergroups.html#instance
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- smartcard.reader.ReaderGroups.readergroups.__init__
  smartcard.reader.ReaderGroups.readergroups.html#__init__
  Function
  Method
  PUBLIC
  Create a single instance of innerreadergroups on first call
- smartcard.reader.ReaderGroups.readergroups.__getattr__
  smartcard.reader.ReaderGroups.readergroups.html#__getattr__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCReaderGroups.pcscinnerreadergroups
  smartcard.pcsc.PCSCReaderGroups.pcscinnerreadergroups.html
  Class
  Class
  PUBLIC
  Smartcard PCSC readers groups inner class.
- smartcard.pcsc.PCSCReaderGroups.pcscinnerreadergroups.__init__
  smartcard.pcsc.PCSCReaderGroups.pcscinnerreadergroups.html#__init__
  Function
  Method
  PUBLIC
  Constructor.
- smartcard.pcsc.PCSCReaderGroups.pcscinnerreadergroups.unremovablegroups
  smartcard.pcsc.PCSCReaderGroups.pcscinnerreadergroups.html#unremovablegroups
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pcsc.PCSCReaderGroups.pcscinnerreadergroups.getreadergroups
  smartcard.pcsc.PCSCReaderGroups.pcscinnerreadergroups.html#getreadergroups
  Function
  Method
  PUBLIC
  Returns the list of smartcard reader groups.
- smartcard.pcsc.PCSCReaderGroups.pcscinnerreadergroups.addreadergroup
  smartcard.pcsc.PCSCReaderGroups.pcscinnerreadergroups.html#addreadergroup
  Function
  Method
  PUBLIC
  Add a reader group
- smartcard.pcsc.PCSCReaderGroups.pcscinnerreadergroups.removereadergroup
  smartcard.pcsc.PCSCReaderGroups.pcscinnerreadergroups.html#removereadergroup
  Function
  Method
  PUBLIC
  Remove a reader group
- smartcard.pcsc.PCSCReaderGroups.PCSCReaderGroups
  smartcard.pcsc.PCSCReaderGroups.PCSCReaderGroups.html
  Class
  Class
  PUBLIC
  PCSC readers groups.
- smartcard.pcsc.PCSCReaderGroups.PCSCReaderGroups.__init__
  smartcard.pcsc.PCSCReaderGroups.PCSCReaderGroups.html#__init__
  Function
  Method
  PUBLIC
  Create a single instance of pcscinnerreadergroups on first call
- smartcard.pcsc.PCSCReaderGroups.PCSCReaderGroups.innerclazz
  smartcard.pcsc.PCSCReaderGroups.PCSCReaderGroups.html#innerclazz
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pyro.PyroReader.PyroReader
  smartcard.pyro.PyroReader.PyroReader.html
  Class
  Class
  PUBLIC
  Remote reader class.
- smartcard.pyro.PyroReader.PyroReader.__init__
  smartcard.pyro.PyroReader.PyroReader.html#__init__
  Function
  Method
  PUBLIC
  Constructs a new Remote Reader client implementation from a Pyro URI.
- smartcard.pyro.PyroReader.PyroReader.uri
  smartcard.pyro.PyroReader.PyroReader.html#uri
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pyro.PyroReader.PyroReader.reader
  smartcard.pyro.PyroReader.PyroReader.html#reader
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pyro.PyroReader.PyroReader.name
  smartcard.pyro.PyroReader.PyroReader.html#name
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pyro.PyroReader.PyroReader.addtoreadergroup
  smartcard.pyro.PyroReader.PyroReader.html#addtoreadergroup
  Function
  Method
  PUBLIC
  Add reader to a reader group.
- smartcard.pyro.PyroReader.PyroReader.removefromreadergroup
  smartcard.pyro.PyroReader.PyroReader.html#removefromreadergroup
  Function
  Method
  PUBLIC
  Remove a reader from a reader group
- smartcard.pyro.PyroReader.PyroReader.createConnection
  smartcard.pyro.PyroReader.PyroReader.html#createConnection
  Function
  Method
  PUBLIC
  Return a card connection thru a remote reader.
- smartcard.pyro.PyroReader.PyroReader.Factory
  smartcard.pyro.PyroReader.PyroReader.Factory.html
  Class
  Class
  PUBLIC
  Undocumented
- smartcard.pyro.PyroReader.PyroReader.Factory.create
  smartcard.pyro.PyroReader.PyroReader.Factory.html#create
  Function
  Static Method
  PUBLIC
  Undocumented
- smartcard.pyro.PyroReader.PyroReader.readers
  smartcard.pyro.PyroReader.PyroReader.html#readers
  Function
  Static Method
  PUBLIC
  Undocumented
- smartcard.pyro.server.PyroDaemon.PyroDaemon
  smartcard.pyro.server.PyroDaemon.PyroDaemon.html
  Class
  Class
  PUBLIC
  Singleton class to wrap the pyro daemon.
- smartcard.pyro.server.PyroDaemon.PyroDaemon._PyroDaemon
  smartcard.pyro.server.PyroDaemon.PyroDaemon._PyroDaemon.html
  Class
  Class
  PRIVATE
  The pyro daemon actual wrapper class.
- smartcard.pyro.server.PyroDaemon.PyroDaemon._PyroDaemon.__init__
  smartcard.pyro.server.PyroDaemon.PyroDaemon._PyroDaemon.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.pyro.server.PyroDaemon.PyroDaemon._PyroDaemon.daemon
  smartcard.pyro.server.PyroDaemon.PyroDaemon._PyroDaemon.html#daemon
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pyro.server.PyroDaemon.PyroDaemon._PyroDaemon.handler
  smartcard.pyro.server.PyroDaemon.PyroDaemon._PyroDaemon.html#handler
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pyro.server.PyroDaemon.PyroDaemon._PyroDaemon.__call__
  smartcard.pyro.server.PyroDaemon.PyroDaemon._PyroDaemon.html#__call__
  Function
  Method
  PUBLIC
  Ctrl+c handler that will gracefully shutdown the server upon Ctrl+C signal
- smartcard.pyro.server.PyroDaemon.PyroDaemon._PyroDaemon.connect
  smartcard.pyro.server.PyroDaemon.PyroDaemon._PyroDaemon.html#connect
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.pyro.server.PyroDaemon.PyroDaemon._PyroDaemon.disconnect
  smartcard.pyro.server.PyroDaemon.PyroDaemon._PyroDaemon.html#disconnect
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.pyro.server.PyroDaemon.PyroDaemon._PyroDaemon.start
  smartcard.pyro.server.PyroDaemon.PyroDaemon._PyroDaemon.html#start
  Function
  Method
  PUBLIC
  start pyro daemon.
- smartcard.pyro.server.PyroDaemon.PyroDaemon.instance
  smartcard.pyro.server.PyroDaemon.PyroDaemon.html#instance
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- smartcard.pyro.server.PyroDaemon.PyroDaemon.__init__
  smartcard.pyro.server.PyroDaemon.PyroDaemon.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.pyro.server.PyroDaemon.PyroDaemon.__getattr__
  smartcard.pyro.server.PyroDaemon.PyroDaemon.html#__getattr__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.pyro.server.PyroDaemon.PyroDaemonThread
  smartcard.pyro.server.PyroDaemon.PyroDaemonThread.html
  Class
  Class
  PUBLIC
  Thread running the Pyro daemon server.
- smartcard.pyro.server.PyroDaemon.PyroDaemonThread.__init__
  smartcard.pyro.server.PyroDaemon.PyroDaemonThread.html#__init__
  Function
  Method
  PUBLIC
  Initialize pyro event server with command line arguments. For a complete list of command line arguments, see pyro documentation for pyro-es start script.
- smartcard.pyro.server.PyroDaemon.PyroDaemonThread.daemon
  smartcard.pyro.server.PyroDaemon.PyroDaemonThread.html#daemon
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pyro.server.PyroDaemon.PyroDaemonThread.run
  smartcard.pyro.server.PyroDaemon.PyroDaemonThread.html#run
  Function
  Method
  PUBLIC
  Starts Pyro daemon.
- smartcard.pyro.server.PyroEventServer.PyroEventServer
  smartcard.pyro.server.PyroEventServer.PyroEventServer.html
  Class
  Class
  PUBLIC
  Thread running the Pyro Event server.
- smartcard.pyro.server.PyroEventServer.PyroEventServer.__init__
  smartcard.pyro.server.PyroEventServer.PyroEventServer.html#__init__
  Function
  Method
  PUBLIC
  Initialize pyro event server with command line arguments. For a complete list of command line arguments, see pyro documentation for pyro-es start script.
- smartcard.pyro.server.PyroEventServer.PyroEventServer.args
  smartcard.pyro.server.PyroEventServer.PyroEventServer.html#args
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pyro.server.PyroEventServer.PyroEventServer.handler
  smartcard.pyro.server.PyroEventServer.PyroEventServer.html#handler
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pyro.server.PyroEventServer.PyroEventServer.starter
  smartcard.pyro.server.PyroEventServer.PyroEventServer.html#starter
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pyro.server.PyroEventServer.PyroEventServer.run
  smartcard.pyro.server.PyroEventServer.PyroEventServer.html#run
  Function
  Method
  PUBLIC
  Starts Pyro naming server with command line arguments (see pyro documentation)
- smartcard.pyro.server.PyroEventServer.PyroEventServer.stop
  smartcard.pyro.server.PyroEventServer.PyroEventServer.html#stop
  Function
  Method
  PUBLIC
  Shutdown pyro event server.
- smartcard.pyro.server.PyroEventServer.PyroEventServer.waitStarted
  smartcard.pyro.server.PyroEventServer.PyroEventServer.html#waitStarted
  Function
  Method
  PUBLIC
  wait until name server is started.
- smartcard.pyro.server.PyroEventServer.PyroEventServer.__call__
  smartcard.pyro.server.PyroEventServer.PyroEventServer.html#__call__
  Function
  Method
  PUBLIC
  Ctrl+c handler that will gracefully shutdown the server upon Ctrl+C signal
- smartcard.pyro.server.PyroNameServer.PyroNameServer
  smartcard.pyro.server.PyroNameServer.PyroNameServer.html
  Class
  Class
  PUBLIC
  Thread running the Pyro Name server.
- smartcard.pyro.server.PyroNameServer.PyroNameServer.__init__
  smartcard.pyro.server.PyroNameServer.PyroNameServer.html#__init__
  Function
  Method
  PUBLIC
  Initialize pyro name server with command line arguments. For a complete list of command line arguments, see pyro documentation for pyro-ns start script.
- smartcard.pyro.server.PyroNameServer.PyroNameServer.args
  smartcard.pyro.server.PyroNameServer.PyroNameServer.html#args
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pyro.server.PyroNameServer.PyroNameServer.handler
  smartcard.pyro.server.PyroNameServer.PyroNameServer.html#handler
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pyro.server.PyroNameServer.PyroNameServer.host
  smartcard.pyro.server.PyroNameServer.PyroNameServer.html#host
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pyro.server.PyroNameServer.PyroNameServer.bcport
  smartcard.pyro.server.PyroNameServer.PyroNameServer.html#bcport
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pyro.server.PyroNameServer.PyroNameServer.bcaddr
  smartcard.pyro.server.PyroNameServer.PyroNameServer.html#bcaddr
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pyro.server.PyroNameServer.PyroNameServer.identification
  smartcard.pyro.server.PyroNameServer.PyroNameServer.html#identification
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pyro.server.PyroNameServer.PyroNameServer.getShutdownArgs
  smartcard.pyro.server.PyroNameServer.PyroNameServer.html#getShutdownArgs
  Function
  Method
  PUBLIC
  return command line arguments for shutting down the server; this command line is built from the name server startup arguments.
- smartcard.pyro.server.PyroNameServer.PyroNameServer.listall
  smartcard.pyro.server.PyroNameServer.PyroNameServer.html#listall
  Function
  Method
  PUBLIC
  List pyro namespace.
- smartcard.pyro.server.PyroNameServer.PyroNameServer.ping
  smartcard.pyro.server.PyroNameServer.PyroNameServer.html#ping
  Function
  Method
  PUBLIC
  Ping pyro naming server.
- smartcard.pyro.server.PyroNameServer.PyroNameServer.run
  smartcard.pyro.server.PyroNameServer.PyroNameServer.html#run
  Function
  Method
  PUBLIC
  Starts Pyro naming server with command line arguments (see pyro documentation)
- smartcard.pyro.server.PyroNameServer.PyroNameServer.stop
  smartcard.pyro.server.PyroNameServer.PyroNameServer.html#stop
  Function
  Method
  PUBLIC
  Shutdown pyro naming server.
- smartcard.pyro.server.PyroNameServer.PyroNameServer.waitStarted
  smartcard.pyro.server.PyroNameServer.PyroNameServer.html#waitStarted
  Function
  Method
  PUBLIC
  wait until name server is started.
- smartcard.pyro.server.PyroNameServer.PyroNameServer.__call__
  smartcard.pyro.server.PyroNameServer.PyroNameServer.html#__call__
  Function
  Method
  PUBLIC
  Ctrl+c handler that will gracefully shutdown the server upon Ctrl+C signal
- smartcard.pyro.server.RemoteCardConnection.RemoteCardConnection
  smartcard.pyro.server.RemoteCardConnection.RemoteCardConnection.html
  Class
  Class
  PUBLIC
  Remote connection class. Handles connection with a card inserted inside a remote PC.
- smartcard.pyro.server.RemoteCardConnection.RemoteCardConnection.__init__
  smartcard.pyro.server.RemoteCardConnection.RemoteCardConnection.html#__init__
  Function
  Method
  PUBLIC
  Construct a new remote card connection.
- smartcard.pyro.server.RemoteReaderServer.RemoteReader
  smartcard.pyro.server.RemoteReaderServer.RemoteReader.html
  Class
  Class
  PUBLIC
  Remote reader class that embeds a local reader.
- smartcard.pyro.server.RemoteReaderServer.RemoteReader.__init__
  smartcard.pyro.server.RemoteReaderServer.RemoteReader.html#__init__
  Function
  Method
  PUBLIC
  Encapsulate a local reader and publish as a pyro remote reader.
- smartcard.pyro.server.RemoteReaderServer.RemoteReader.readerobj
  smartcard.pyro.server.RemoteReaderServer.RemoteReader.html#readerobj
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pyro.server.RemoteReaderServer.RemoteReader.name
  smartcard.pyro.server.RemoteReaderServer.RemoteReader.html#name
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pyro.server.RemoteReaderServer.RemoteReader.addtoreadergroup
  smartcard.pyro.server.RemoteReaderServer.RemoteReader.html#addtoreadergroup
  Function
  Method
  PUBLIC
  Add reader to a reader group.
- smartcard.pyro.server.RemoteReaderServer.RemoteReader.removefromreadergroup
  smartcard.pyro.server.RemoteReaderServer.RemoteReader.html#removefromreadergroup
  Function
  Method
  PUBLIC
  Remove a reader from a reader group
- smartcard.pyro.server.RemoteReaderServer.RemoteReader.createConnection
  smartcard.pyro.server.RemoteReaderServer.RemoteReader.html#createConnection
  Function
  Method
  PUBLIC
  Return a card connection thru the reader.
- smartcard.pyro.server.RemoteReaderServer.RemoteReaderServer
  smartcard.pyro.server.RemoteReaderServer.RemoteReaderServer.html
  Class
  Class
  PUBLIC
  Monitor local readers, and publish them as remote pyro readers.
- smartcard.pyro.server.RemoteReaderServer.RemoteReaderServer.__init__
  smartcard.pyro.server.RemoteReaderServer.RemoteReaderServer.html#__init__
  Function
  Method
  PUBLIC
  Starts pyro name server and constructs reader name space.
- smartcard.pyro.server.RemoteReaderServer.RemoteReaderServer.pn
  smartcard.pyro.server.RemoteReaderServer.RemoteReaderServer.html#pn
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pyro.server.RemoteReaderServer.RemoteReaderServer.ns
  smartcard.pyro.server.RemoteReaderServer.RemoteReaderServer.html#ns
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pyro.server.RemoteReaderServer.RemoteReaderServer.daemon
  smartcard.pyro.server.RemoteReaderServer.RemoteReaderServer.html#daemon
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pyro.server.RemoteReaderServer.RemoteReaderServer.remotereaders
  smartcard.pyro.server.RemoteReaderServer.RemoteReaderServer.html#remotereaders
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.pyro.server.RemoteReaderServer.RemoteReaderServer.start
  smartcard.pyro.server.RemoteReaderServer.RemoteReaderServer.html#start
  Function
  Method
  PUBLIC
  Start pyro daemon and accept incoming requests.
- smartcard.pyro.server.RemoteReaderServer.RemoteReaderServer.update
  smartcard.pyro.server.RemoteReaderServer.RemoteReaderServer.html#update
  Function
  Method
  PUBLIC
  Called when a local reader is added or removed. Create remote pyro reader objects for added readers. Delete remote pyro reader objects for removed readers.
- smartcard.reader.ReaderFactory.ReaderFactory
  smartcard.reader.ReaderFactory.ReaderFactory.html
  Class
  Class
  PUBLIC
  Class to create readers from reader type id.
- smartcard.reader.ReaderFactory.ReaderFactory.factories
  smartcard.reader.ReaderFactory.ReaderFactory.html#factories
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- smartcard.reader.ReaderFactory.ReaderFactory.factorymethods
  smartcard.reader.ReaderFactory.ReaderFactory.html#factorymethods
  Attribute
  Class Variable
  PUBLIC
  Undocumented
- smartcard.reader.ReaderFactory.ReaderFactory.createReader
  smartcard.reader.ReaderFactory.ReaderFactory.html#createReader
  Function
  Static Method
  PUBLIC
  Static method to create a reader from a reader clazz.
- smartcard.reader.ReaderFactory.ReaderFactory.readers
  smartcard.reader.ReaderFactory.ReaderFactory.html#readers
  Function
  Static Method
  PUBLIC
  Undocumented
- smartcard.sw.ErrorChecker.ErrorChecker
  smartcard.sw.ErrorChecker.ErrorChecker.html
  Class
  Class
  PUBLIC
  Base class for status word error checking strategies.
- smartcard.sw.ErrorChecker.ErrorChecker.__call__
  smartcard.sw.ErrorChecker.ErrorChecker.html#__call__
  Function
  Method
  PUBLIC
  Called to test data, sw1 and sw2 for error.
- smartcard.sw.ErrorCheckingChain.ErrorCheckingChain
  smartcard.sw.ErrorCheckingChain.ErrorCheckingChain.html
  Class
  Class
  PUBLIC
  The error checking chain is a list of response apdu status word (sw1, sw2) error check strategies. Each strategy in the chain is called until an error is detected. A `smartcard.sw.SWExceptions` exception is raised when an error is detected...
- smartcard.sw.ErrorCheckingChain.ErrorCheckingChain.__init__
  smartcard.sw.ErrorCheckingChain.ErrorCheckingChain.html#__init__
  Function
  Method
  PUBLIC
  constructor. Appends a strategy to the `ErrorCheckingChain` chain.
- smartcard.sw.ErrorCheckingChain.ErrorCheckingChain.strategy
  smartcard.sw.ErrorCheckingChain.ErrorCheckingChain.html#strategy
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.sw.ErrorCheckingChain.ErrorCheckingChain.chain
  smartcard.sw.ErrorCheckingChain.ErrorCheckingChain.html#chain
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.sw.ErrorCheckingChain.ErrorCheckingChain.excludes
  smartcard.sw.ErrorCheckingChain.ErrorCheckingChain.html#excludes
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.sw.ErrorCheckingChain.ErrorCheckingChain.next
  smartcard.sw.ErrorCheckingChain.ErrorCheckingChain.html#next
  Function
  Method
  PUBLIC
  Returns next error checking strategy.
- smartcard.sw.ErrorCheckingChain.ErrorCheckingChain.addFilterException
  smartcard.sw.ErrorCheckingChain.ErrorCheckingChain.html#addFilterException
  Function
  Method
  PUBLIC
  Add an exception filter to the error checking chain.
- smartcard.sw.ErrorCheckingChain.ErrorCheckingChain.end
  smartcard.sw.ErrorCheckingChain.ErrorCheckingChain.html#end
  Function
  Method
  PUBLIC
  Returns True if this is the end of the error checking strategy chain.
- smartcard.sw.ErrorCheckingChain.ErrorCheckingChain.__call__
  smartcard.sw.ErrorCheckingChain.ErrorCheckingChain.html#__call__
  Function
  Method
  PUBLIC
  Called to test data, sw1 and sw2 for error on the chain.
- smartcard.sw.ISO7816_4ErrorChecker.iso7816_4SW
  smartcard.sw.ISO7816_4ErrorChecker.html#iso7816_4SW
  Attribute
  Variable
  PUBLIC
  Undocumented
- smartcard.sw.ISO7816_4ErrorChecker.ISO7816_4ErrorChecker
  smartcard.sw.ISO7816_4ErrorChecker.ISO7816_4ErrorChecker.html
  Class
  Class
  PUBLIC
  ISO7816-4 error checking strategy.
- smartcard.sw.ISO7816_4ErrorChecker.ISO7816_4ErrorChecker.__call__
  smartcard.sw.ISO7816_4ErrorChecker.ISO7816_4ErrorChecker.html#__call__
  Function
  Method
  PUBLIC
  Called to test data, sw1 and sw2 for error.
- smartcard.sw.ISO7816_4_SW1ErrorChecker.iso7816_4SW1
  smartcard.sw.ISO7816_4_SW1ErrorChecker.html#iso7816_4SW1
  Attribute
  Variable
  PUBLIC
  Undocumented
- smartcard.sw.ISO7816_4_SW1ErrorChecker.ISO7816_4_SW1ErrorChecker
  smartcard.sw.ISO7816_4_SW1ErrorChecker.ISO7816_4_SW1ErrorChecker.html
  Class
  Class
  PUBLIC
  ISO7816-4 error checker based on status word sw1 only.
- smartcard.sw.ISO7816_4_SW1ErrorChecker.ISO7816_4_SW1ErrorChecker.__call__
  smartcard.sw.ISO7816_4_SW1ErrorChecker.ISO7816_4_SW1ErrorChecker.html#__call__
  Function
  Method
  PUBLIC
  Called to test data, sw1 and sw2 for error.
- smartcard.sw.ISO7816_8ErrorChecker.iso7816_8SW
  smartcard.sw.ISO7816_8ErrorChecker.html#iso7816_8SW
  Attribute
  Variable
  PUBLIC
  Undocumented
- smartcard.sw.ISO7816_8ErrorChecker.ISO7816_8ErrorChecker
  smartcard.sw.ISO7816_8ErrorChecker.ISO7816_8ErrorChecker.html
  Class
  Class
  PUBLIC
  ISO7816-8 error checker.
- smartcard.sw.ISO7816_8ErrorChecker.ISO7816_8ErrorChecker.__call__
  smartcard.sw.ISO7816_8ErrorChecker.ISO7816_8ErrorChecker.html#__call__
  Function
  Method
  PUBLIC
  Called to test data, sw1 and sw2 for error.
- smartcard.sw.ISO7816_9ErrorChecker.iso7816_9SW
  smartcard.sw.ISO7816_9ErrorChecker.html#iso7816_9SW
  Attribute
  Variable
  PUBLIC
  Undocumented
- smartcard.sw.ISO7816_9ErrorChecker.ISO7816_9ErrorChecker
  smartcard.sw.ISO7816_9ErrorChecker.ISO7816_9ErrorChecker.html
  Class
  Class
  PUBLIC
  ISO7816-8 error checker.
- smartcard.sw.ISO7816_9ErrorChecker.ISO7816_9ErrorChecker.__call__
  smartcard.sw.ISO7816_9ErrorChecker.ISO7816_9ErrorChecker.html#__call__
  Function
  Method
  PUBLIC
  Called to test data, sw1 and sw2 for error.
- smartcard.sw.SWExceptions.SWException
  smartcard.sw.SWExceptions.SWException.html
  Class
  Exception
  PUBLIC
  Base class for status word exceptions.
- smartcard.sw.SWExceptions.SWException.__init__
  smartcard.sw.SWExceptions.SWException.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.sw.SWExceptions.SWException.message
  smartcard.sw.SWExceptions.SWException.html#message
  Attribute
  Instance Variable
  PUBLIC
  response apdu data
- smartcard.sw.SWExceptions.SWException.data
  smartcard.sw.SWExceptions.SWException.html#data
  Attribute
  Instance Variable
  PUBLIC
  response apdu sw1
- smartcard.sw.SWExceptions.SWException.sw1
  smartcard.sw.SWExceptions.SWException.html#sw1
  Attribute
  Instance Variable
  PUBLIC
  response apdu sw2
- smartcard.sw.SWExceptions.SWException.sw2
  smartcard.sw.SWExceptions.SWException.html#sw2
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.sw.SWExceptions.SWException.__str__
  smartcard.sw.SWExceptions.SWException.html#__str__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.sw.SWExceptions.WarningProcessingException
  smartcard.sw.SWExceptions.WarningProcessingException.html
  Class
  Exception
  PUBLIC
  Raised when a warning processing is detected from sw1, sw2. Examples of warning processing exception: sw1=62 or sw=63 (ISO7816-4).
- smartcard.sw.SWExceptions.WarningProcessingException.__init__
  smartcard.sw.SWExceptions.WarningProcessingException.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.sw.SWExceptions.ExecutionErrorException
  smartcard.sw.SWExceptions.ExecutionErrorException.html
  Class
  Exception
  PUBLIC
  Raised when an execution error is detected from sw1, sw2. Examples of execution error: sw1=64 or sw=65 (ISO7816-4).
- smartcard.sw.SWExceptions.ExecutionErrorException.__init__
  smartcard.sw.SWExceptions.ExecutionErrorException.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.sw.SWExceptions.SecurityRelatedException
  smartcard.sw.SWExceptions.SecurityRelatedException.html
  Class
  Exception
  PUBLIC
  Raised when a security issue is detected from sw1, sw2. Examples of security issue: sw1=66 (ISO7816-4).
- smartcard.sw.SWExceptions.SecurityRelatedException.__init__
  smartcard.sw.SWExceptions.SecurityRelatedException.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.sw.SWExceptions.CheckingErrorException
  smartcard.sw.SWExceptions.CheckingErrorException.html
  Class
  Exception
  PUBLIC
  Raised when a checking error is detected from sw1, sw2. Examples of checking error: sw1=67 to 6F (ISO781604).
- smartcard.sw.SWExceptions.CheckingErrorException.__init__
  smartcard.sw.SWExceptions.CheckingErrorException.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.sw.op21_ErrorChecker.op21_SW
  smartcard.sw.op21_ErrorChecker.html#op21_SW
  Attribute
  Variable
  PUBLIC
  Undocumented
- smartcard.sw.op21_ErrorChecker.op21_ErrorChecker
  smartcard.sw.op21_ErrorChecker.op21_ErrorChecker.html
  Class
  Class
  PUBLIC
  Open platform 2.1 error checker.
- smartcard.sw.op21_ErrorChecker.op21_ErrorChecker.__call__
  smartcard.sw.op21_ErrorChecker.op21_ErrorChecker.html#__call__
  Function
  Method
  PUBLIC
  Called to test data, sw1 and sw2 for error.
- smartcard.wx.main_is_frozen
  smartcard.wx.html#main_is_frozen
  Function
  Function
  PUBLIC
  Undocumented
- smartcard.wx.ICO_SMARTCARD
  smartcard.wx.html#ICO_SMARTCARD
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.wx.ICO_READER
  smartcard.wx.html#ICO_READER
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.wx.APDUHexValidator.hexbyte
  smartcard.wx.APDUHexValidator.html#hexbyte
  Attribute
  Variable
  PUBLIC
  Undocumented
- smartcard.wx.APDUHexValidator.apduregexp
  smartcard.wx.APDUHexValidator.html#apduregexp
  Attribute
  Variable
  PUBLIC
  Undocumented
- smartcard.wx.APDUHexValidator.APDUHexValidator
  smartcard.wx.APDUHexValidator.APDUHexValidator.html
  Class
  Class
  PUBLIC
  A wxValidator that matches APDU in hexadecimal such as: A4 A0 00 00 02 A4A0000002
- smartcard.wx.APDUHexValidator.APDUHexValidator.__init__
  smartcard.wx.APDUHexValidator.APDUHexValidator.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.wx.APDUHexValidator.APDUHexValidator.Clone
  smartcard.wx.APDUHexValidator.APDUHexValidator.html#Clone
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.wx.APDUHexValidator.APDUHexValidator.Validate
  smartcard.wx.APDUHexValidator.APDUHexValidator.html#Validate
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.wx.APDUHexValidator.APDUHexValidator.OnChar
  smartcard.wx.APDUHexValidator.APDUHexValidator.html#OnChar
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.wx.APDUTracerPanel.APDUTracerPanel
  smartcard.wx.APDUTracerPanel.APDUTracerPanel.html
  Class
  Class
  PUBLIC
  No class docstring; 0/1 instance variable, 2/3 methods documented
- smartcard.wx.APDUTracerPanel.APDUTracerPanel.__init__
  smartcard.wx.APDUTracerPanel.APDUTracerPanel.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.wx.APDUTracerPanel.APDUTracerPanel.apdutextctrl
  smartcard.wx.APDUTracerPanel.APDUTracerPanel.html#apdutextctrl
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.APDUTracerPanel.APDUTracerPanel.OnMaxLength
  smartcard.wx.APDUTracerPanel.APDUTracerPanel.html#OnMaxLength
  Function
  Method
  PUBLIC
  Reset text buffer when max length is reached.
- smartcard.wx.APDUTracerPanel.APDUTracerPanel.update
  smartcard.wx.APDUTracerPanel.APDUTracerPanel.html#update
  Function
  Method
  PUBLIC
  CardConnectionObserver callback.
- smartcard.wx.CardAndReaderTreePanel.BaseCardTreeCtrl
  smartcard.wx.CardAndReaderTreePanel.BaseCardTreeCtrl.html
  Class
  Class
  PUBLIC
  Base class for the smart card and reader tree controls.
- smartcard.wx.CardAndReaderTreePanel.BaseCardTreeCtrl.__init__
  smartcard.wx.CardAndReaderTreePanel.BaseCardTreeCtrl.html#__init__
  Function
  Method
  PUBLIC
  Constructor. Initializes a smartcard or reader tree control.
- smartcard.wx.CardAndReaderTreePanel.BaseCardTreeCtrl.clientpanel
  smartcard.wx.CardAndReaderTreePanel.BaseCardTreeCtrl.html#clientpanel
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.CardAndReaderTreePanel.BaseCardTreeCtrl.parent
  smartcard.wx.CardAndReaderTreePanel.BaseCardTreeCtrl.html#parent
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.CardAndReaderTreePanel.BaseCardTreeCtrl.capindex
  smartcard.wx.CardAndReaderTreePanel.BaseCardTreeCtrl.html#capindex
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.CardAndReaderTreePanel.BaseCardTreeCtrl.fldrindex
  smartcard.wx.CardAndReaderTreePanel.BaseCardTreeCtrl.html#fldrindex
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.CardAndReaderTreePanel.BaseCardTreeCtrl.fldropenindex
  smartcard.wx.CardAndReaderTreePanel.BaseCardTreeCtrl.html#fldropenindex
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.CardAndReaderTreePanel.BaseCardTreeCtrl.cardimageindex
  smartcard.wx.CardAndReaderTreePanel.BaseCardTreeCtrl.html#cardimageindex
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.CardAndReaderTreePanel.BaseCardTreeCtrl.readerimageindex
  smartcard.wx.CardAndReaderTreePanel.BaseCardTreeCtrl.html#readerimageindex
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.CardAndReaderTreePanel.BaseCardTreeCtrl.il
  smartcard.wx.CardAndReaderTreePanel.BaseCardTreeCtrl.html#il
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.CardAndReaderTreePanel.BaseCardTreeCtrl.Repaint
  smartcard.wx.CardAndReaderTreePanel.BaseCardTreeCtrl.html#Repaint
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.wx.CardAndReaderTreePanel.CardTreeCtrl
  smartcard.wx.CardAndReaderTreePanel.CardTreeCtrl.html
  Class
  Class
  PUBLIC
  The CardTreeCtrl monitors inserted cards and notifies the application client dialog of any card activation.
- smartcard.wx.CardAndReaderTreePanel.CardTreeCtrl.__init__
  smartcard.wx.CardAndReaderTreePanel.CardTreeCtrl.html#__init__
  Function
  Method
  PUBLIC
  Constructor. Create a smartcard tree control.
- smartcard.wx.CardAndReaderTreePanel.CardTreeCtrl.root
  smartcard.wx.CardAndReaderTreePanel.CardTreeCtrl.html#root
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.CardAndReaderTreePanel.CardTreeCtrl.OnAddCards
  smartcard.wx.CardAndReaderTreePanel.CardTreeCtrl.html#OnAddCards
  Function
  Method
  PUBLIC
  Called when a card is inserted. Adds a smart card to the smartcards tree.
- smartcard.wx.CardAndReaderTreePanel.CardTreeCtrl.OnRemoveCards
  smartcard.wx.CardAndReaderTreePanel.CardTreeCtrl.html#OnRemoveCards
  Function
  Method
  PUBLIC
  Called when a card is removed. Removes a card from the tree.
- smartcard.wx.CardAndReaderTreePanel.ReaderTreeCtrl
  smartcard.wx.CardAndReaderTreePanel.ReaderTreeCtrl.html
  Class
  Class
  PUBLIC
  The ReaderTreeCtrl monitors inserted cards and readers and notifies the application client dialog of any card activation.
- smartcard.wx.CardAndReaderTreePanel.ReaderTreeCtrl.__init__
  smartcard.wx.CardAndReaderTreePanel.ReaderTreeCtrl.html#__init__
  Function
  Method
  PUBLIC
  Constructor. Create a reader tree control.
- smartcard.wx.CardAndReaderTreePanel.ReaderTreeCtrl.mutex
  smartcard.wx.CardAndReaderTreePanel.ReaderTreeCtrl.html#mutex
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.CardAndReaderTreePanel.ReaderTreeCtrl.root
  smartcard.wx.CardAndReaderTreePanel.ReaderTreeCtrl.html#root
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.CardAndReaderTreePanel.ReaderTreeCtrl.AddATR
  smartcard.wx.CardAndReaderTreePanel.ReaderTreeCtrl.html#AddATR
  Function
  Method
  PUBLIC
  Add an ATR to a reader node.
- smartcard.wx.CardAndReaderTreePanel.ReaderTreeCtrl.GetATR
  smartcard.wx.CardAndReaderTreePanel.ReaderTreeCtrl.html#GetATR
  Function
  Method
  PUBLIC
  Return the ATR of the card inserted into the reader.
- smartcard.wx.CardAndReaderTreePanel.ReaderTreeCtrl.OnAddCards
  smartcard.wx.CardAndReaderTreePanel.ReaderTreeCtrl.html#OnAddCards
  Function
  Method
  PUBLIC
  Called when a card is inserted. Adds the smart card child to the reader node.
- smartcard.wx.CardAndReaderTreePanel.ReaderTreeCtrl.OnAddReaders
  smartcard.wx.CardAndReaderTreePanel.ReaderTreeCtrl.html#OnAddReaders
  Function
  Method
  PUBLIC
  Called when a reader is inserted. Adds the smart card reader to the smartcard readers tree.
- smartcard.wx.CardAndReaderTreePanel.ReaderTreeCtrl.OnRemoveCards
  smartcard.wx.CardAndReaderTreePanel.ReaderTreeCtrl.html#OnRemoveCards
  Function
  Method
  PUBLIC
  Called when a card is removed. Removes the card from the tree.
- smartcard.wx.CardAndReaderTreePanel.ReaderTreeCtrl.OnRemoveReaders
  smartcard.wx.CardAndReaderTreePanel.ReaderTreeCtrl.html#OnRemoveReaders
  Function
  Method
  PUBLIC
  Called when a reader is removed. Removes the reader from the smartcard readers tree.
- smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel
  smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel.html
  Class
  Class
  PUBLIC
  Panel containing the smart card and reader tree controls.
- smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel._CardObserver
  smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel._CardObserver.html
  Class
  Class
  PRIVATE
  Inner CardObserver. Gets notified of card insertion removal by the CardMonitor.
- smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel._CardObserver.__init__
  smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel._CardObserver.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel._CardObserver.cardtreectrl
  smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel._CardObserver.html#cardtreectrl
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel._CardObserver.update
  smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel._CardObserver.html#update
  Function
  Method
  PUBLIC
  CardObserver callback that is notified when cards are added or removed.
- smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel._ReaderObserver
  smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel._ReaderObserver.html
  Class
  Class
  PRIVATE
  Inner ReaderObserver. Gets notified of reader insertion/removal by the ReaderMonitor.
- smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel._ReaderObserver.__init__
  smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel._ReaderObserver.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel._ReaderObserver.readertreectrl
  smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel._ReaderObserver.html#readertreectrl
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel._ReaderObserver.update
  smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel._ReaderObserver.html#update
  Function
  Method
  PUBLIC
  ReaderObserver callback that is notified when readers are added or removed.
- smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel.__init__
  smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel.html#__init__
  Function
  Method
  PUBLIC
  Constructor. Create a smartcard and reader tree control on the left-hand side of the application main frame.
- smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel.cardtreectrl
  smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel.html#cardtreectrl
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel.cardtreecardobserver
  smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel.html#cardtreecardobserver
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel.cardmonitor
  smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel.html#cardmonitor
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel.readertreectrl
  smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel.html#readertreectrl
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel.readertreereaderobserver
  smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel.html#readertreereaderobserver
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel.readermonitor
  smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel.html#readermonitor
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel.readertreecardobserver
  smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel.html#readertreecardobserver
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel.OnDestroy
  smartcard.wx.CardAndReaderTreePanel.CardAndReaderTreePanel.html#OnDestroy
  Function
  Method
  PUBLIC
  Called on panel destruction.
- smartcard.wx.ReaderToolbar.ReaderComboBox
  smartcard.wx.ReaderToolbar.ReaderComboBox.html
  Class
  Class
  PUBLIC
  No class docstring; 0/1 instance variable, 2/2 methods documented
- smartcard.wx.ReaderToolbar.ReaderComboBox.__init__
  smartcard.wx.ReaderToolbar.ReaderComboBox.html#__init__
  Function
  Method
  PUBLIC
  Constructor. Registers as ReaderObserver to get notifications of reader insertion/removal.
- smartcard.wx.ReaderToolbar.ReaderComboBox.readermonitor
  smartcard.wx.ReaderToolbar.ReaderComboBox.html#readermonitor
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.ReaderToolbar.ReaderComboBox.update
  smartcard.wx.ReaderToolbar.ReaderComboBox.html#update
  Function
  Method
  PUBLIC
  Toolbar ReaderObserver callback that is notified when readers are added or removed.
- smartcard.wx.ReaderToolbar.ReaderToolbar
  smartcard.wx.ReaderToolbar.ReaderToolbar.html
  Class
  Class
  PUBLIC
  ReaderToolbar. Contains controls to select a reader from a listbox and connect to the cards.
- smartcard.wx.ReaderToolbar.ReaderToolbar.__init__
  smartcard.wx.ReaderToolbar.ReaderToolbar.html#__init__
  Function
  Method
  PUBLIC
  Constructor, creating the reader toolbar.
- smartcard.wx.ReaderToolbar.ReaderToolbar.readercombobox
  smartcard.wx.ReaderToolbar.ReaderToolbar.html#readercombobox
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardAppEventObserver.SimpleSCardAppEventObserver
  smartcard.wx.SimpleSCardAppEventObserver.SimpleSCardAppEventObserver.html
  Class
  Class
  PUBLIC
  This interface defines the event handlers called by the SimpleSCardApp.
- smartcard.wx.SimpleSCardAppEventObserver.SimpleSCardAppEventObserver.__init__
  smartcard.wx.SimpleSCardAppEventObserver.SimpleSCardAppEventObserver.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardAppEventObserver.SimpleSCardAppEventObserver.selectedcard
  smartcard.wx.SimpleSCardAppEventObserver.SimpleSCardAppEventObserver.html#selectedcard
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardAppEventObserver.SimpleSCardAppEventObserver.selectedreader
  smartcard.wx.SimpleSCardAppEventObserver.SimpleSCardAppEventObserver.html#selectedreader
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardAppEventObserver.SimpleSCardAppEventObserver.OnActivateCard
  smartcard.wx.SimpleSCardAppEventObserver.SimpleSCardAppEventObserver.html#OnActivateCard
  Function
  Method
  PUBLIC
  Called when a card is activated in the reader tree control or toolbar.
- smartcard.wx.SimpleSCardAppEventObserver.SimpleSCardAppEventObserver.OnActivateReader
  smartcard.wx.SimpleSCardAppEventObserver.SimpleSCardAppEventObserver.html#OnActivateReader
  Function
  Method
  PUBLIC
  Called when a reader is activated in the reader tree control or toolbar.
- smartcard.wx.SimpleSCardAppEventObserver.SimpleSCardAppEventObserver.OnDeactivateCard
  smartcard.wx.SimpleSCardAppEventObserver.SimpleSCardAppEventObserver.html#OnDeactivateCard
  Function
  Method
  PUBLIC
  Called when a card is deactivated in the reader tree control or toolbar.
- smartcard.wx.SimpleSCardAppEventObserver.SimpleSCardAppEventObserver.OnDeselectCard
  smartcard.wx.SimpleSCardAppEventObserver.SimpleSCardAppEventObserver.html#OnDeselectCard
  Function
  Method
  PUBLIC
  Called when a card is selected in the reader tree control or toolbar.
- smartcard.wx.SimpleSCardAppEventObserver.SimpleSCardAppEventObserver.OnSelectCard
  smartcard.wx.SimpleSCardAppEventObserver.SimpleSCardAppEventObserver.html#OnSelectCard
  Function
  Method
  PUBLIC
  Called when a card is selected in the reader tree control or toolbar.
- smartcard.wx.SimpleSCardAppEventObserver.SimpleSCardAppEventObserver.OnSelectReader
  smartcard.wx.SimpleSCardAppEventObserver.SimpleSCardAppEventObserver.html#OnSelectReader
  Function
  Method
  PUBLIC
  Called when a reader is selected in the reader tree control or toolbar.
- smartcard.wx.SimpleSCardAppFrame.BlankPanel
  smartcard.wx.SimpleSCardAppFrame.BlankPanel.html
  Class
  Class
  PUBLIC
  A blank panel in case no panel is provided to SimpleSCardApp.
- smartcard.wx.SimpleSCardAppFrame.BlankPanel.__init__
  smartcard.wx.SimpleSCardAppFrame.BlankPanel.html#__init__
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel
  smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.html
  Class
  Class
  PUBLIC
  The panel that contains the Card/Reader TreeCtrl and the user provided Panel.
- smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.__init__
  smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.html#__init__
  Function
  Method
  PUBLIC
  Constructor. Creates the panel with two panels:
- smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.parent
  smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.html#parent
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.selectedcard
  smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.html#selectedcard
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.dialogpanel
  smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.html#dialogpanel
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.readertreepanel
  smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.html#readertreepanel
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.ActivateCard
  smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.html#ActivateCard
  Function
  Method
  PUBLIC
  Activate a card.
- smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.DeactivateCard
  smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.html#DeactivateCard
  Function
  Method
  PUBLIC
  Deactivate a card.
- smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.OnActivateCard
  smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.html#OnActivateCard
  Function
  Method
  PUBLIC
  Called when the user activates a card in the tree.
- smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.OnActivateReader
  smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.html#OnActivateReader
  Function
  Method
  PUBLIC
  Called when the user activates a reader in the tree.
- smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.OnItemCollapsed
  smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.html#OnItemCollapsed
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.OnCardRightClick
  smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.html#OnCardRightClick
  Function
  Method
  PUBLIC
  Called when user right-clicks a node in the card tree control.
- smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.connectID
  smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.html#connectID
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.disconnectID
  smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.html#disconnectID
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.OnReaderRightClick
  smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.html#OnReaderRightClick
  Function
  Method
  PUBLIC
  Called when user right-clicks a node in the reader tree control.
- smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.OnConnect
  smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.html#OnConnect
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.OnDisconnect
  smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.html#OnDisconnect
  Function
  Method
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.OnSelectCard
  smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.html#OnSelectCard
  Function
  Method
  PUBLIC
  Called when the user selects a card in the tree.
- smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.OnSelectReader
  smartcard.wx.SimpleSCardAppFrame.TreeAndUserPanelPanel.html#OnSelectReader
  Function
  Method
  PUBLIC
  Called when the user selects a reader in the tree.
- smartcard.wx.SimpleSCardAppFrame.SimpleSCardAppFrame
  smartcard.wx.SimpleSCardAppFrame.SimpleSCardAppFrame.html
  Class
  Class
  PUBLIC
  The main frame of the simple smartcard application.
- smartcard.wx.SimpleSCardAppFrame.SimpleSCardAppFrame.__init__
  smartcard.wx.SimpleSCardAppFrame.SimpleSCardAppFrame.html#__init__
  Function
  Method
  PUBLIC
  Constructor. Creates the frame with two panels:
- smartcard.wx.SimpleSCardAppFrame.SimpleSCardAppFrame.treeuserpanel
  smartcard.wx.SimpleSCardAppFrame.SimpleSCardAppFrame.html#treeuserpanel
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardAppFrame.SimpleSCardAppFrame.toolbar
  smartcard.wx.SimpleSCardAppFrame.SimpleSCardAppFrame.html#toolbar
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardAppFrame.SimpleSCardAppFrame.apdutracerpanel
  smartcard.wx.SimpleSCardAppFrame.SimpleSCardAppFrame.html#apdutracerpanel
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardAppFrame.SimpleSCardAppFrame.OnCloseFrame
  smartcard.wx.SimpleSCardAppFrame.SimpleSCardAppFrame.html#OnCloseFrame
  Function
  Method
  PUBLIC
  Called when frame is closed, i.e. on wx.EVT_CLOSE
- smartcard.wx.SimpleSCardAppFrame.SimpleSCardAppFrame.OnExit
  smartcard.wx.SimpleSCardAppFrame.SimpleSCardAppFrame.html#OnExit
  Function
  Method
  PUBLIC
  Called when frame application exits.
- smartcard.wx.SimpleSCardAppFrame.SimpleSCardAppFrame.OnReaderComboBox
  smartcard.wx.SimpleSCardAppFrame.SimpleSCardAppFrame.html#OnReaderComboBox
  Function
  Method
  PUBLIC
  Called when the user activates a reader in the toolbar combo box.
- smartcard.wx.SimpleSCardApp.TR_SMARTCARD
  smartcard.wx.SimpleSCardApp.html#TR_SMARTCARD
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardApp.TR_READER
  smartcard.wx.SimpleSCardApp.html#TR_READER
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardApp.TB_SMARTCARD
  smartcard.wx.SimpleSCardApp.html#TB_SMARTCARD
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardApp.TB_READER
  smartcard.wx.SimpleSCardApp.html#TB_READER
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardApp.PANEL_APDUTRACER
  smartcard.wx.SimpleSCardApp.html#PANEL_APDUTRACER
  Attribute
  Constant
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardApp.SimpleSCardApp
  smartcard.wx.SimpleSCardApp.SimpleSCardApp.html
  Class
  Class
  PUBLIC
  The SimpleSCardApp class represents the smart card application. SimpleSCardApp is a subclass of wx.App.
- smartcard.wx.SimpleSCardApp.SimpleSCardApp.__init__
  smartcard.wx.SimpleSCardApp.SimpleSCardApp.html#__init__
  Function
  Method
  PUBLIC
  Constructor for simple smart card application.
- smartcard.wx.SimpleSCardApp.SimpleSCardApp.appname
  smartcard.wx.SimpleSCardApp.SimpleSCardApp.html#appname
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardApp.SimpleSCardApp.apppanel
  smartcard.wx.SimpleSCardApp.SimpleSCardApp.html#apppanel
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardApp.SimpleSCardApp.appstyle
  smartcard.wx.SimpleSCardApp.SimpleSCardApp.html#appstyle
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardApp.SimpleSCardApp.appicon
  smartcard.wx.SimpleSCardApp.SimpleSCardApp.html#appicon
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardApp.SimpleSCardApp.pos
  smartcard.wx.SimpleSCardApp.SimpleSCardApp.html#pos
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardApp.SimpleSCardApp.size
  smartcard.wx.SimpleSCardApp.SimpleSCardApp.html#size
  Attribute
  Instance Variable
  PUBLIC
  Undocumented
- smartcard.wx.SimpleSCardApp.SimpleSCardApp.OnInit
  smartcard.wx.SimpleSCardApp.SimpleSCardApp.html#OnInit
  Function
  Method
  PUBLIC
  Create and display application frame.
- smartcard.wx.SimpleSCardApp.SimpleSCardApp.frame
  smartcard.wx.SimpleSCardApp.SimpleSCardApp.html#frame
  Attribute
  Instance Variable
  PUBLIC
  Undocumented